@@ -565,6 +565,12 @@ public:
         return MOS_STATUS_SUCCESS;
     };
 
+    virtual bool IsBindlessHeapInUse(
+        PRENDERHAL_INTERFACE pRenderHal)
+    {
+        return false;
+    }
+
     //! \brief    Allocates scratch space buffer.
     //! \details  On some new pltforms, a single scratch space buffer may be allocated and used for
     //!           all threads.
