@@ -161,6 +161,34 @@ protected:
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
     virtual MOS_STATUS DecompressInterlacedSurf(PVPHAL_SURFACE pSource) override;
+
+    //!
+    //! \brief    Update SamplerStateParams associated with a surface state for composite
+    //! \param    [in] pSamplerStateParams
+    //!           Pointer to SamplerStateParams
+    //! \param    [in] pEntry
+    //!           Pointer to Surface state
+    //! \param    [in] pRenderData
+    //!           Pointer to RenderData
+    //! \param    [in] uLayerNum
+    //!           Layer total number
+    //! \param    [in] SamplerFilterMode
+    //!           SamplerFilterMode to be set
+    //! \param    [out] pSamplerIndex
+    //!           Pointer to Sampler Index
+    //! \param    [out] pSurface
+    //!           point to Surface
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise MOS_STATUS_UNKNOWN
+    //!
+    virtual MOS_STATUS SetSamplerFilterMode(
+        PMHW_SAMPLER_STATE_PARAM       &pSamplerStateParams,
+        PRENDERHAL_SURFACE_STATE_ENTRY  pEntry,
+        PVPHAL_RENDERING_DATA_COMPOSITE pRenderData,
+        uint32_t                        uLayerNum,
+        MHW_SAMPLER_FILTER_MODE         SamplerFilterMode,
+        int32_t                        *pSamplerIndex,
+        PVPHAL_SURFACE                  pSource) override;
 };
 
 #endif // __VPHAL_RENDER_COMPOSITE_XE_XPM_H__
