@@ -61,12 +61,6 @@ extern "C" {
 #define ABS(a)      (((a) < 0) ? (-(a)) : (a))
 #endif
 
-//!
-//! \def WITHIN_BOUNDS(a, min, max)
-//! Calcualte if \a a within the range of  [\a min, \a max].
-//!
-#define WITHIN_BOUNDS(a, min, max) ( ((a) >= (min)) && ((a) <= (max)) )
-
 //!
 //! \def VPHAL_ABS(x)
 //! Calcualte the Abslute value of \a x.
@@ -75,14 +69,6 @@ extern "C" {
 
 #define VPHAL_PI                   3.14159265358979324f //!< Definition the const pi
 
-//!
-//! \def SAME_SIZE_RECT(rect1, rect2)
-//! Compare if the size of two rectangles is the same
-//!
-#define SAME_SIZE_RECT(rect1, rect2)                                            \
-    (((rect1).right  - (rect1).left == (rect2).right  - (rect2).left) &&        \
-     ((rect1).bottom - (rect1).top  == (rect2).bottom - (rect2).top))
-
 //!
 //! \def RECT1_EQUALS_RECT2(rect1, rect2)
 //! Compare if two rectangles has the same coordinate
@@ -107,24 +93,6 @@ extern "C" {
 #define AVS_TBL_COEF_PREC         6           //!< Table coef precision (after decimal point
 #define SAME_SAMPLE_THRESHOLD     1000        //!< When checking whether 2 timestamps are the same, leave room for some error
 
-//!
-//! \def MEDIA_IS_HDCONTENT(dwWidth, dwHeight)
-//! Determine if the size of content is HD
-//!
-#define MEDIA_SDCONTENT_MAX_WIDTH        720
-#define MEDIA_SDCONTENT_MAX_PAL_HEIGHT   576
-#define MEDIA_SDCONTENT_MAX_SW_WIDTH     768
-#define MEDIA_IS_HDCONTENT(dwWidth, dwHeight)    ((dwWidth > MEDIA_SDCONTENT_MAX_SW_WIDTH) || (dwHeight > MEDIA_SDCONTENT_MAX_PAL_HEIGHT))
-
-//! \brief  Surface cache attributes
-//!
-#define VPHAL_SET_SURF_MEMOBJCTL(VpField, GmmUsageEnum)                                                         \
-    {                                                                                                           \
-        Usage = GmmUsageEnum;                                                                                   \
-        MemObjCtrl = pOsInterface->pfnCachePolicyGetMemoryObject(Usage, pOsInterface->pfnGetGmmClientContext(pOsInterface));                                        \
-        VpField = MemObjCtrl.DwordValue;                                                                        \
-    }
-
 // Compositing Block size
 #define VPHAL_COMP_BLOCK_WIDTH  16
 #define VPHAL_COMP_BLOCK_HEIGHT 16
@@ -146,30 +114,6 @@ extern "C" {
 #define VPHAL_MAX_CHANNELS              2
 #define VPHAL_MAX_FUTURE_FRAMES         18       //!< maximum future frames supported in VPHAL
 
-
-//!
-//! \brief Vphal Output chroma configuration enum
-//!
-typedef enum _VPHAL_CHROMA_SUBSAMPLING
-{
-    CHROMA_SUBSAMPLING_TOP_CENTER       = 0,
-    CHROMA_SUBSAMPLING_CENTER_CENTER,
-    CHROMA_SUBSAMPLING_BOTTOM_CENTER,
-    CHROMA_SUBSAMPLING_TOP_LEFT,
-    CHROMA_SUBSAMPLING_CENTER_LEFT,
-    CHROMA_SUBSAMPLING_BOTTOM_LEFT
-} VPHAL_CHROMA_SUBSAMPLING;
-
-//!
-//! \brief Vphal Gamma Values configuration enum
-//!
-typedef enum _VPHAL_GAMMA_VALUE
-{
-    GAMMA_1P0 = 0,
-    GAMMA_2P2,
-    GAMMA_2P6
-} VPHAL_GAMMA_VALUE;
-
 typedef enum _VPHAL_DP_ROTATION_MODE
 {
     VPHAL_DP_ROTATION_NV12_AVG            = 0,   //!< nv12 -> yuy2 by chroma average
@@ -201,16 +145,6 @@ typedef enum _VPHAL_DP_ROTATION_MODE
                                                 _a == CSpace_BT601Gray   || \
                                                 _a == CSpace_BT2020)
 
-//!
-//! \def IS_YUV_FULL_RANGE(_a)
-//! Check if YUV full range
-//!
-#define IS_YUV_FULL_RANGE(_a)                  (_a == CSpace_BT601_FullRange       || \
-                                                _a == CSpace_BT709_FullRange       || \
-                                                _a == CSpace_BT601Gray_FullRange   || \
-                                                _a == CSpace_BT2020_FullRange)
-
-
 //!
 //! \def SET_VPHAL_OUTPUT_PIPE(_a, _Pipe)
 //! Set the output pipe
@@ -257,24 +191,6 @@ typedef enum _VPHAL_DP_ROTATION_MODE
 //!
 #define SET_VPHAL_MMC_STATE(_a, _bEnableMMC)          (_a->bEnableMMC =  _bEnableMMC)                    // Set the Component
 
-
-//!
-//! Union   VPHAL_HALF_PRECISION_FLOAT
-//! \brief  Vphal half precision float type
-//!
-typedef union _VPHAL_HALF_PRECISION_FLOAT
-{
-    struct
-    {
-        uint16_t      Mantissa : 10;
-        uint16_t      Exponent : 5;
-        uint16_t      Sign     : 1;
-    };
-
-    uint16_t value;
-} VPHAL_HALF_PRECISION_FLOAT, PVPHAL_HALF_PRECISION_FLOAT;
-
-
 //!
 //! \brief Vphal 3DLUT Channel Mapping enum
 //!
@@ -285,21 +201,6 @@ typedef enum _VPHAL_3DLUT_CHANNEL_MAPPING
     CHANNEL_MAPPING_VUY_RGB          = 1 << 1,
 } VPHAL_3DLUT_CHANNEL_MAPPING;
 
-
-//!
-//! Structure VPHAL_GAMUT_PARAMS
-//! \brief IECP Gamut Mapping Parameters
-//!
-typedef struct _VPHAL_GAMUT_PARAMS
-{
-    VPHAL_GAMUT_MODE    GCompMode;
-    VPHAL_GAMUT_MODE    GExpMode;
-    VPHAL_GAMMA_VALUE   GammaValue;
-    uint32_t            dwAttenuation;       //!< U2.10 [0, 1024] 0 = No down scaling, 1024 = Full down scaling
-    float               displayRGBW_x[4];
-    float               displayRGBW_y[4];
-} VPHAL_GAMUT_PARAMS, *PVPHAL_GAMUT_PARAMS;
-
 //!
 //! Structure VPHAL_CONSTRICTION_PARAMS
 //! \brief Constriction parameters
@@ -309,48 +210,6 @@ typedef struct _VPHAL_CONSTRICTION_PARAMS
     RECT                rcConstriction;
 } VPHAL_CONSTRICTION_PARAMS, *PVPHAL_CONSTRICTION_PARAMS;
 
-//!
-//! \brief    Performs Color Space Convert for Sample 8 bit
-//! \details  Performs Color Space Convert from Src Color Spase to Dst Color Spase
-//! \param    [out] pOutput
-//!           Pointer to VPHAL_COLOR_SAMPLE_8
-//! \param    [in] pInput
-//!           Pointer to VPHAL_COLOR_SAMPLE_8
-//! \param    [in] srcCspace
-//!           Source Color Space 
-//! \param    [in] dstCspace
-//!           Dest Color Space 
-//! \return   bool
-//!           Return true if successful, otherwise false
-//!
-bool VpHal_CSC_8(
-    VPHAL_COLOR_SAMPLE_8    *pOutput,
-    VPHAL_COLOR_SAMPLE_8    *pInput,
-    VPHAL_CSPACE            srcCspace,
-    VPHAL_CSPACE            dstCspace);
-
-//!
-//! \brief
-//! \details  Get CSC matrix in a form usable by Vebox, SFC and IECP kernels
-//! \param    [in] SrcCspace
-//!           Source Cspace
-//! \param    [in] DstCspace
-//!           Destination Cspace
-//! \param    [out] pfCscCoeff
-//!           [3x3] Coefficients matrix
-//! \param    [out] pfCscInOffset
-//!           [3x1] Input Offset matrix
-//! \param    [out] pfCscOutOffset
-//!           [3x1] Output Offset matrix
-//! \return   void
-//!
-void VpHal_GetCscMatrix(
-    VPHAL_CSPACE                        SrcCspace,
-    VPHAL_CSPACE                        DstCspace,
-    float*                              pfCscCoeff,
-    float*                              pfCscInOffset,
-    float*                              pfCscOutOffset);
-
 //!
 //! \brief    sinc
 //! \details  Calculate sinc(x)
@@ -478,18 +337,6 @@ MOS_STATUS VpHal_WriteSurface (
     uint32_t                    uBpp,
     const uint8_t*              pSrc);
 
-//!
-//! \brief    Get the color pack type of a surface
-//! \details  Map mos surface format to color pack format and return.
-//!           For unknown format return VPHAL_COLORPACK_UNKNOWN
-//! \param    [in] Format
-//!           MOS_FORMAT of a surface
-//! \return   VPHAL_COLORPACK
-//!           Color pack type of the surface
-//!
-VPHAL_COLORPACK VpHal_GetSurfaceColorPack (
-    MOS_FORMAT                  Format);
-
 //!
 //! \brief    Decide whether Chroma up sampling is needed
 //! \param    [in] pSource
@@ -516,17 +363,6 @@ bool VpHal_IsChromaDownSamplingNeeded(
     PVPHAL_SURFACE          pSource,
     PVPHAL_SURFACE          pTarget);
 
-//! \brief    Get the bit depth of a surface
-//! \details  Get bit depth of input mos surface format and return.
-//!           For unknown format return 0
-//! \param    [in] Format
-//!           MOS_FORMAT of a surface
-//! \return   uint32_t
-//!           Bit depth of the surface
-//!
-uint32_t VpHal_GetSurfaceBitDepth(
-    MOS_FORMAT      Format);
-
 //!
 //! \brief      Get the scale ratio
 //! \details    Get the scale ratio from input surface to output surface
@@ -546,16 +382,6 @@ void VpHal_GetScalingRatio(
     float*                      pfScaleX,
     float*                      pfScaleY);
 
-//! \brief    Transfer float type to half precision float type
-//! \details  Transfer float type to half precision float (16bit) type
-//! \param    [in] fInput
-//!           input FP32 number
-//! \return   uint16_t
-//!           half precision float value in bit
-//!
-uint16_t VpHal_FloatToHalfFloat(
-    float     fInput);
-
 //! \brief    Transfer float type to half precision float type
 //! \details  Transfer float type to half precision float (16bit) type
 //! \param    [in] fInput
@@ -566,9 +392,6 @@ uint16_t VpHal_FloatToHalfFloat(
 uint16_t VpHal_FloatToHalfFloatA(
     float fInputA);
 
-MOS_SURFACE VpHal_ConvertVphalSurfaceToMosSurface(
-    PVPHAL_SURFACE pSurface);
-
 bool IsSyncFreeNeededForMMCSurface(PVPHAL_SURFACE pSurface, PMOS_INTERFACE pOsInterface);
 
 #ifdef __cplusplus
