@@ -32,7 +32,7 @@
 #include "igcodeckrn_g12.h"
 #include "codeckrnheader.h"
 
-struct KernelHeader
+struct KernelHeaderMpegG12
 {
     uint32_t m_kernelCount;
 
@@ -1020,11 +1020,11 @@ CodechalEncodeMpeg2G12::CodechalEncodeMpeg2G12(
 {
     CODECHAL_ENCODE_FUNCTION_ENTER;
 
-    CODECHAL_ENCODE_ASSERT(m_osInterface);
+    CODECHAL_ENCODE_CHK_NULL_NO_STATUS_RETURN(m_osInterface);
 
     m_kuidCommon = IDR_CODEC_HME_DS_SCOREBOARD_KERNEL;
 
-    Mos_CheckVirtualEngineSupported(m_osInterface, false, true);
+    m_osInterface->pfnVirtualEngineSupported(m_osInterface, false, true);
 
     pfnGetKernelHeaderAndSize = GetKernelHeaderAndSize;
 
@@ -1110,7 +1110,7 @@ MOS_STATUS CodechalEncodeMpeg2G12::SetAndPopulateVEHintParams(
 
 MOS_STATUS CodechalEncodeMpeg2G12::SubmitCommandBuffer(
     PMOS_COMMAND_BUFFER cmdBuffer,
-    int32_t             bNullRendering)
+    bool             bNullRendering)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
@@ -1142,7 +1142,7 @@ MOS_STATUS CodechalEncodeMpeg2G12::GetKernelHeaderAndSize(
     CODECHAL_ENCODE_CHK_NULL_RETURN(krnHeader);
     CODECHAL_ENCODE_CHK_NULL_RETURN(krnSize);
 
-    auto kernelHeaderTable = (KernelHeader *)binary;
+    auto kernelHeaderTable = (KernelHeaderMpegG12 *)binary;
     PCODECHAL_KERNEL_HEADER currKrnHeader;
 
     if (operation == ENC_BRC)
@@ -1367,7 +1367,7 @@ MOS_STATUS CodechalEncodeMpeg2G12::UserFeatureKeyReport()
 #if (_DEBUG || _RELEASE_INTERNAL)
 
     // VE2.0 Reporting
-    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VE_CTXSCHEDULING_ID, MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(m_osInterface));
+    CodecHalEncode_WriteKey(__MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VE_CTXSCHEDULING_ID, MOS_VE_CTXBASEDSCHEDULING_SUPPORTED(m_osInterface), m_osInterface->pOsContext);
 
 #endif // _DEBUG || _RELEASE_INTERNAL
 
