@@ -152,7 +152,6 @@ protected:
     MediaFeatureManager    *m_featureManager   = nullptr;
     AvcPipeline            *m_avcPipeline      = nullptr;
     DecodeAllocator        *m_allocator        = nullptr;
-    PMOS_INTERFACE          m_osInterface      = nullptr;
     AvcBasicFeature        *m_avcBasicFeature  = nullptr;
     MhwVdboxVdencInterface *m_vdencInterface   = nullptr;
     CodechalHwInterface    *m_hwInterface      = nullptr;
@@ -168,7 +167,7 @@ protected:
     uint32_t m_picturePatchListSize = 0;
     uint32_t m_sliceStatesSize      = 0;
     uint32_t m_slicePatchListSize   = 0;
-MEDIA_CLASS_DEFINE_END(AvcDecodePktXe_M_Base)
+MEDIA_CLASS_DEFINE_END(decode__AvcDecodePktXe_M_Base)
 };
 }
 #endif // !__DECODE_AVC_PACKET_H__
