@@ -33,6 +33,7 @@
 #include "vp_vebox_common.h"
 #include "vp_render_sfc_base.h"
 #include "vp_filter.h"
+#include "vp_user_feature_control.h"
 
 namespace vp {
 
@@ -157,6 +158,26 @@ public:
     //!
     virtual MOS_STATUS SetSfcCSCParams(PSFC_CSC_PARAMS cscParams) override;
 
+    //!
+    //! \brief    Setup CSC Params for Vebox back end
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetVeboxCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
+    //!
+    //! \brief    Setup CSC Params for Vebox front end
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetVeboxFeCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
     //!
     //! \brief    Setup CSC Params for Vebox back end
     //! \details  Setup surface CSC Params for Vebox
@@ -803,6 +824,18 @@ protected:
     MOS_STATUS SetupVebox3DLutForHDR(
         PMHW_VEBOX_STATE_CMD_PARAMS pVeboxStateCmdParams);
 
+    MOS_STATUS SetupVeboxExternal3DLutforHDR(
+        PMHW_VEBOX_STATE_CMD_PARAMS pVeboxStateCmdParams);
+
+protected:
+#if (_DEBUG || _RELEASE_INTERNAL)
+    virtual MOS_STATUS StallBatchBuffer(
+        PMOS_COMMAND_BUFFER cmdBuffer)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+#endif
+
 private:
 
     //!
@@ -899,6 +932,7 @@ protected:
     bool                        m_useKernelResource        = false;               //!< Use Vebox Kernel Resource 
     uint32_t                    m_inputDepth               = 0;
     std::shared_ptr<mhw::vebox::Itf> m_veboxItf            = nullptr;
+    vp::VpUserFeatureControl   *m_vpUserFeatureControl = nullptr;
 
 MEDIA_CLASS_DEFINE_END(vp__VpVeboxCmdPacketLegacy)
 };
