@@ -254,3 +254,10 @@ MOS_STATUS VpPlatformInterfacsXe2_Lpm::InitPolicyRules(VP_POLICY_RULES &rules)
     rules.is1K1DLutSurfaceInUse = true;
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_STATUS VpPlatformInterfacsXe2_Lpm::InitVpFeatureSupportBits()
+{
+    VP_FUNC_CALL();
+    VP_PUBLIC_CHK_STATUS_RETURN(VpPlatformInterface::InitVpFeatureSupportBits());
+    return MOS_STATUS_SUCCESS;
+}
