@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -113,7 +113,7 @@ MOS_STATUS Mpeg2PipelineXe_Lpm_Plus_Base::CreateSubPackets(DecodeSubPacketManage
     DECODE_CHK_STATUS(subPacketManager.Register(
         DecodePacketId(this, mpeg2PictureSubPacketId), *pictureDecodePkt));
 
-    if (codecSettings.mode = CODECHAL_DECODE_MODE_MPEG2VLD)
+    if (codecSettings.mode == CODECHAL_DECODE_MODE_MPEG2VLD)
     {
         Mpeg2DecodeSlcPktXe_Lpm_Plus_Base *sliceDecodePkt = MOS_New(Mpeg2DecodeSlcPktXe_Lpm_Plus_Base, this, m_hwInterface);
         DECODE_CHK_NULL(sliceDecodePkt);
@@ -192,6 +192,13 @@ MOS_STATUS Mpeg2PipelineXe_Lpm_Plus_Base::Prepare(void *params)
         inputParameters.currDecodedPicRes          = m_basicFeature->m_destSurface.OsResource;
         inputParameters.numUsedVdbox               = m_numVdbox;
 
+        CODECHAL_DEBUG_TOOL(
+            if (m_streamout != nullptr)  
+            {  
+                DECODE_CHK_STATUS(m_streamout->InitStatusReportParam(inputParameters));  
+            }  
+        );
+
         m_statusReport->Init(&inputParameters);
     }
 
@@ -217,6 +224,12 @@ MOS_STATUS Mpeg2PipelineXe_Lpm_Plus_Base::Execute()
 
 #if (_DEBUG || _RELEASE_INTERNAL)
             DECODE_CHK_STATUS(StatusCheck());
+#ifdef _MMC_SUPPORTED
+            if (m_mmcState != nullptr)
+            {
+                m_mmcState->ReportSurfaceMmcMode(&(m_basicFeature->m_destSurface));
+            }
+#endif
 #endif
 
             // Only update user features for the first frame.
