@@ -92,6 +92,13 @@ MOS_STATUS Vp8PipelineXe_Lpm_Plus_Base::Prepare(void *params)
             inputParameters.currDecodedPicRes          = m_basicFeature->m_destSurface.OsResource;
             inputParameters.numUsedVdbox               = m_numVdbox;
 
+            CODECHAL_DEBUG_TOOL(
+                if (m_streamout != nullptr)  
+                {  
+                    DECODE_CHK_STATUS(m_streamout->InitStatusReportParam(inputParameters));  
+                }  
+            );
+
             m_statusReport->Init(&inputParameters);
         }
     }
