@@ -154,6 +154,8 @@ namespace encode {
         auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
         ENCODE_CHK_NULL_RETURN(brcFeature);
 
+        ENCODE_CHK_STATUS_RETURN(AddCondBBEndFor2ndPass(*commandBuffer))
+
         MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
         ENCODE_CHK_NULL_RETURN(perfProfiler);
         ENCODE_CHK_STATUS_RETURN(perfProfiler->AddPerfCollectStartCmd(
@@ -308,7 +310,8 @@ namespace encode {
         uint32_t numTiles = 1;
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileNum, numTiles);
 
-        uint16_t numTilesPerPipe = 1;
+        uint16_t numTilesPerPipe     = (uint16_t)(numTiles / m_pipeline->GetPipeNum());
+        uint16_t imbalanceTilesOnVD0 = (uint16_t)(numTiles % m_pipeline->GetPipeNum());
 
         auto brcFeature = dynamic_cast<Av1Brc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1BrcFeature));
         ENCODE_CHK_NULL_RETURN(brcFeature);
@@ -342,18 +345,26 @@ namespace encode {
 
         if (m_pipeline->GetPipeNum() > 1)
         {
-            hucPakStitchDmem->TileSizeRecord_offset[0] = tileRecordOffset; //hevcFrameStatsOffset.tileSizeRecord;
+            // set Pak Int output offset at index 0
+            hucPakStitchDmem->TileSizeRecord_offset[0] = tileRecordOffset;
             hucPakStitchDmem->VDENCSTAT_offset[0]      = brcFeature->IsBRCEnabled() ? av1TileStatsOffset.uiVdencStatistics : 0xFFFFFFFF;
 
-            for (uint32_t i = 0; i < numTiles; i++)
+            // set Pak Int tiles count & input offset for VD0 dedicatedly due to possible extra tile on VD0
+            hucPakStitchDmem->NumTiles[0]  = numTilesPerPipe + imbalanceTilesOnVD0;
+            hucPakStitchDmem->NumSlices[0] = numTilesPerPipe + imbalanceTilesOnVD0; 
+
+            hucPakStitchDmem->TileSizeRecord_offset[1] = tileRecordOffset;
+            hucPakStitchDmem->VDENCSTAT_offset[1]      = av1TileStatsOffset.uiVdencStatistics;
+
+            for (uint32_t i = 1; i < m_pipeline->GetPipeNum(); i++)
             {
                 hucPakStitchDmem->NumTiles[i]  = numTilesPerPipe;
-                hucPakStitchDmem->NumSlices[i] = numTilesPerPipe;  // Assuming 1 slice/ tile. To do: change this later.
+                hucPakStitchDmem->NumSlices[i] = numTilesPerPipe; 
 
                 // Statistics are dumped out at a tile level. Driver shares with kernel starting offset of each pipe statistic.
                 // Offset is calculated by adding size of statistics/pipe to the offset in combined statistics region.
-                hucPakStitchDmem->TileSizeRecord_offset[i + 1] = (i * numTilesPerPipe * CODECHAL_CACHELINE_SIZE) + tileRecordOffset;
-                hucPakStitchDmem->VDENCSTAT_offset[i + 1]      = av1TileStatsOffset.uiVdencStatistics + av1StatsSize.uiVdencStatistics * i * numTilesPerPipe;
+                hucPakStitchDmem->TileSizeRecord_offset[i + 1] = (i * numTilesPerPipe + imbalanceTilesOnVD0) * CODECHAL_CACHELINE_SIZE + tileRecordOffset;
+                hucPakStitchDmem->VDENCSTAT_offset[i + 1]      = (i * numTilesPerPipe + imbalanceTilesOnVD0) * av1StatsSize.uiVdencStatistics + av1TileStatsOffset.uiVdencStatistics;
             }
         }
 
@@ -377,7 +388,7 @@ namespace encode {
         PMOS_RESOURCE osResource = nullptr;
         uint32_t      offset     = 0;
 
-        m_statusReport->GetAddress(statusReportSumSquareError, osResource, offset);
+        ENCODE_CHK_STATUS_RETURN(m_statusReport->GetAddress(statusReportSumSquareError, osResource, offset));
 
         for (auto i = 0; i < 3; i++)  // 64 bit SSE values for luma/ chroma channels need to be copied
         {
@@ -644,6 +655,27 @@ namespace encode {
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS Av1PakIntegratePkt::AddCondBBEndFor2ndPass(MOS_COMMAND_BUFFER &cmdBuffer)
+    {
+        ENCODE_FUNC_CALL();
+
+        if (m_pipeline->IsSingleTaskPhaseSupported() || m_pipeline->IsFirstPass() || m_pipeline->GetPassNum() == 1)
+        {
+            return MOS_STATUS_SUCCESS;
+        }
+
+        auto &miConditionalBatchBufferEndParams = m_miItf->MHW_GETPAR_F(MI_CONDITIONAL_BATCH_BUFFER_END)();
+        miConditionalBatchBufferEndParams       = {};
+
+        // VDENC uses HuC FW generated semaphore for conditional 2nd pass
+        miConditionalBatchBufferEndParams.presSemaphoreBuffer =
+            m_basicFeature->m_recycleBuf->GetBuffer(VdencBrcPakMmioBuffer, 0);
+
+        ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_CONDITIONAL_BATCH_BUFFER_END)(&cmdBuffer));
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     MHW_SETPAR_DECL_SRC(HUC_IMEM_STATE, Av1PakIntegratePkt)
     {
         params.kernelDescriptor = m_vdboxHucPakIntKernelDescriptor;
