@@ -228,6 +228,12 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             picParams->pic_init_qp_minus26 + 26 + slcParams->slice_qp_delta;
     }
 
+    if (slcParams->num_ref_idx_l0_active_minus1 >= CODEC_MAX_NUM_REF_FIELD || slcParams->num_ref_idx_l1_active_minus1 >= CODEC_MAX_NUM_REF_FIELD)
+    {
+        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+        return MOS_STATUS_INVALID_PARAMETER;
+    }
+
     for (uint32_t sliceCount = 0; sliceCount < m_basicFeature->m_numSlices; sliceCount++)
     {
         if (m_pictureCodingType != I_TYPE)
@@ -265,6 +271,11 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             {
                 for (uint8_t i = 0; i < (slcParams->num_ref_idx_l0_active_minus1 + 1); i++)
                 {
+                    if (slcParams->RefPicList[0][i].FrameIdx >= CODEC_AVC_MAX_NUM_REF_FRAME)
+                    {
+                        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
                     auto index = m_picIdx[slcParams->RefPicList[0][i].FrameIdx].ucPicIdx;
                     if (m_refList[index]->ucFrameId < hwInvalidFrameId)
                     {
@@ -284,7 +295,12 @@ MOS_STATUS AvcReferenceFrames::UpdateSlice()
             if (m_pictureCodingType == B_TYPE)
             {
                 for (uint8_t i = 0; i < (slcParams->num_ref_idx_l1_active_minus1 + 1); i++)
-                {
+                {                
+                    if (slcParams->RefPicList[1][i].FrameIdx >= CODEC_AVC_MAX_NUM_REF_FRAME)
+                    {
+                        ENCODE_ASSERTMESSAGE("Invalid slice parameters.");
+                        return MOS_STATUS_INVALID_PARAMETER;
+                    }
                     auto index = m_picIdx[slcParams->RefPicList[1][i].FrameIdx].ucPicIdx;
                     if (m_refList[index]->ucFrameId < hwInvalidFrameId)
                     {
@@ -563,6 +579,10 @@ MHW_SETPAR_DECL_SRC(VDENC_AVC_IMG_STATE, AvcReferenceFrames)
         {
             auto id = slcParams->RefPicList[LIST_1][0].FrameIdx;
             params.longtermReferenceFrameBwdRef0Indicator = (id < CODEC_AVC_MAX_NUM_REF_FRAME) && CodecHal_PictureIsLongTermRef(picParams->RefFrameList[id]);
+            if (id >= CODEC_AVC_MAX_NUM_REF_FRAME)
+            {
+                return MOS_STATUS_INVALID_PARAMETER;
+            }             
             id = m_picIdx[id].ucPicIdx;
             params.bwdRefIdx0ReferencePicture = m_refList[id]->ucFrameId;
             refPoc[1][0] = (uint8_t)m_refList[id]->iFieldOrderCnt[0];
