@@ -154,4 +154,9 @@ MOS_STATUS BufferQueue::DestoryResource(void* resource)
     return MOS_STATUS_SUCCESS;
 }
 
+void BufferQueue::SetResourceType(ResourceType resType)
+{ 
+    m_resourceType = resType; 
+}
+
 }
\ No newline at end of file
