@@ -125,6 +125,7 @@ inline SurfaceFormat MosFormatToVdencSurfaceReconFormat(MOS_FORMAT format)
         return SurfaceFormat::p010Variant;
     case Format_R10G10B10A2:
         return SurfaceFormat::r10g10b10a2;
+    case Format_Y210:
     case Format_Y216:
         return SurfaceFormat::y216Variant;
     case Format_Y410:
@@ -568,7 +569,7 @@ protected:
     {
         _MHW_SETCMD_CALLBASE(VDENC_PIPE_BUF_ADDR_STATE);
 
-        MHW_RESOURCE_PARAMS resourceParams;
+        MHW_RESOURCE_PARAMS resourceParams = {};
 
         if (params.surfaceRaw)
         {
@@ -649,10 +650,11 @@ protected:
                 &resourceParams));
         }
 
+        // SCC will use BwdRef0 as extra slot to store IBC if max fwd ref num is 3.
         typename cmd_t::VDENC_Reference_Picture_CMD *fwdRefs[] =
             {&cmd.FwdRef0, &cmd.FwdRef1, &cmd.FwdRef2, &cmd.BwdRef0};
         uint32_t fwdRefsDwLoaction[] =
-            {_MHW_CMD_DW_LOCATION(FwdRef0), _MHW_CMD_DW_LOCATION(FwdRef1), _MHW_CMD_DW_LOCATION(FwdRef2)};
+            {_MHW_CMD_DW_LOCATION(FwdRef0), _MHW_CMD_DW_LOCATION(FwdRef1), _MHW_CMD_DW_LOCATION(FwdRef2), _MHW_CMD_DW_LOCATION(BwdRef0)};
 
         typename cmd_t::VDENC_Down_Scaled_Reference_Picture_CMD *fwdRefsDsStage1[] =
             {&cmd.DsFwdRef0, &cmd.DsFwdRef1};
@@ -1144,7 +1146,7 @@ protected:
     DO_FIELD(DW6, TileStreaminOffset, params.tileStreamInOffset);                                                         \
                                                                                                                           \
     DO_FIELD(DW7, RowStoreOffsetEnable, cmd.DW4.TileStartCtbY == 0 ? params.tileEnable : 0);                              \
-    DO_FIELD(DW7, TileRowstoreOffset, cmd.DW4.TileStartCtbY == 0 ? cmd.DW4.TileStartCtbX / 32 : 0);                       \
+    DO_FIELD(DW7, TileRowstoreOffset, params.tileRowstoreOffset);                                                         \
                                                                                                                           \
     DO_FIELD(DW8, TileStreamoutOffsetEnable, params.tileEnable);                                                          \
     DO_FIELD(DW8, TileStreamoutOffset, params.tileId * 19);                                                               \
