@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -61,7 +61,33 @@ struct PerfEntry
     uint32_t    beginRegisterValue[8];      //!< Begin register value
     uint32_t    endRegisterValue[8];        //!< End register value
     uint32_t    beginCpuTime[2];            //!< Begin CPU Time Stamp
-    uint32_t    reserved[14];               //!< Reserved[14]
+    uint32_t    bitstreamSize;              //!< frame level: bitstreamSize
+    uint32_t    SSEY;                       //!< frame level: SSEY 
+    uint32_t    SSEU;                       //!< frame level: SSEU 
+    uint32_t    SSEV;                       //!< frame level: SSEV
+    union
+    {
+        uint32_t DWMeanSsimLayer1_YU;
+        struct
+        {
+            uint32_t MeanSsimLayer1_Y : 12,  // [11:0]
+                DW3_Res_15_12 : 4,           // [15:12]
+                MeanSsimLayer1_U : 12,       // [27:16]
+                DW3_Res_31_18 : 4;           // [31:28]
+        };
+    };
+    union
+    {
+        uint32_t DWMeanSsimLayer1_V;
+        struct
+        {
+            uint32_t MeanSsimLayer1_V : 12,  // [11:0]
+                DW4_Res_15_12 : 4,           // [15:12]
+                MeanSsimLayer1Part_Y : 12,   // [27:16]
+                DW4_Res_31_18 : 4;           // [31:28]
+        };
+    };
+    uint32_t    reserved[8];                //!< Reserved[8]
     uint64_t    beginTimeClockValue;        //!< Begin timestamp
     uint64_t    endTimeClockValue;          //!< End timestamp
 };
@@ -139,8 +165,9 @@ MediaPerfProfiler::MediaPerfProfiler()
     {
         // m_mutex is destroyed after MemNinja report, this will cause fake memory leak,
         // the following 2 lines is to circumvent Memninja counter validation and log parser
-        MosUtilities::MosAtomicDecrement(&MosUtilities::m_mosMemAllocCounter);
+        MosUtilities::MosAtomicDecrement(MosUtilities::m_mosMemAllocCounter);
         MOS_MEMNINJA_FREE_MESSAGE(m_mutex, __FUNCTION__, __FILE__, __LINE__);
+        PRINT_DESTROY_MEMORY(MT_MOS_DESTROY_MEMORY, MT_NORMAL, MT_MEMORY_PTR, (int64_t)(m_mutex), __FUNCTION__, __FILE__, __LINE__);
     }
     else
     {
@@ -285,6 +312,26 @@ MOS_STATUS MediaPerfProfiler::Initialize(void* context, MOS_INTERFACE *osInterfa
         m_multiprocess,
         __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_MUL_PROC,
         MediaUserSetting::Group::Device);
+
+    // Read multi header support
+    ReadUserSetting(
+        userSettingPtr,
+        m_mergeheader,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_MER_HEADER,
+        MediaUserSetting::Group::Device);
+
+    // Read parallel execution support
+    bool addPid = false;
+    ReadUserSetting(
+        userSettingPtr,
+        addPid,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_PARALLEL_EXEC,
+        MediaUserSetting::Group::Device);
+
+    if (addPid)
+    {
+        m_outputFileName += "-" + std::to_string(MosUtilities::MosGetPid());
+    }
     // Read memory information register address
     int8_t regIndex = 0;
     for (regIndex = 0; regIndex < 8; regIndex++)
@@ -296,6 +343,13 @@ MOS_STATUS MediaPerfProfiler::Initialize(void* context, MOS_INTERFACE *osInterfa
             MediaUserSetting::Group::Device);
     }
 
+    // Read multi processes single binary flag
+    ReadUserSetting(
+        userSettingPtr,
+        m_multiprocesssinglebin,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_MUL_PROC_SINGLE_BIN,
+        MediaUserSetting::Group::Device);
+
     PMOS_RESOURCE  pPerfStoreBuffer = (PMOS_RESOURCE)MOS_AllocAndZeroMemory(sizeof(MOS_RESOURCE));
     m_perfStoreBufferMap[pOsContext] = pPerfStoreBuffer;
     // Allocate the buffer which store the performance data
@@ -634,6 +688,120 @@ MOS_STATUS MediaPerfProfiler::AddPerfCollectEndCmd(
     return status;
 }
 
+MOS_STATUS MediaPerfProfiler::AddStoreBitstreamSizeCmd(
+    void                           *context,
+    MOS_INTERFACE                  *osInterface,
+    std::shared_ptr<mhw::mi::Itf>& miItf,
+    MOS_COMMAND_BUFFER             *cmdBuffer,
+    uint32_t                       reg)
+{
+    MOS_STATUS status = MOS_STATUS_SUCCESS;
+    
+    if (m_profilerEnabled == 0)
+    {
+        return status;
+    }
+
+    CHK_NULL_RETURN(context);
+    CHK_NULL_RETURN(osInterface);
+    CHK_NULL_RETURN(miItf);
+    CHK_NULL_RETURN(cmdBuffer);
+
+    PMOS_CONTEXT pOsContext = osInterface->pOsContext;
+    CHK_NULL_RETURN(pOsContext);
+
+    uint32_t perfDataIndex = m_contextIndexMap[context];
+
+    CHK_STATUS_RETURN(StoreRegister(
+        osInterface, 
+        miItf, 
+        cmdBuffer, 
+        BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, bitstreamSize), 
+        reg));
+
+    return status;
+}
+    
+MOS_STATUS MediaPerfProfiler::CopyMemData(
+    std::shared_ptr<mhw::mi::Itf>& miItf,
+    PMOS_COMMAND_BUFFER            cmdBuffer,
+    MOS_CONTEXT_HANDLE             pOsContext,
+    PMOS_RESOURCE                  presSrc,
+    uint32_t                       dwSrcOffset,
+    uint32_t                       dwDstOffset)
+{
+    CHK_NULL_RETURN(miItf);
+
+    auto &miCpyMemMemParams = miItf->MHW_GETPAR_F(MI_COPY_MEM_MEM)();
+    miCpyMemMemParams       = {};
+    
+    miCpyMemMemParams.presSrc     = presSrc;
+    miCpyMemMemParams.dwSrcOffset = dwSrcOffset;
+    miCpyMemMemParams.presDst     = m_perfStoreBufferMap[(PMOS_CONTEXT)pOsContext];
+    miCpyMemMemParams.dwDstOffset = dwDstOffset;
+    CHK_STATUS_RETURN(miItf->MHW_ADDCMD_F(MI_COPY_MEM_MEM)(cmdBuffer));
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS MediaPerfProfiler::AddCopyQualityMetricCmd(
+    void                           *context,
+    MOS_INTERFACE                  *osInterface,
+    std::shared_ptr<mhw::mi::Itf>& miItf,
+    MOS_COMMAND_BUFFER             *cmdBuffer,
+    UMD_QUALITY_METRIC_ITEM        item,
+    PMOS_RESOURCE                  presSrc,
+    uint32_t                       dwSrcOffset)
+{
+    MOS_STATUS status = MOS_STATUS_SUCCESS;
+    uint32_t   offset = 0;
+
+    if (m_profilerEnabled == 0)
+    {
+        return status;
+    }
+
+    CHK_NULL_RETURN(context);
+    CHK_NULL_RETURN(osInterface);
+    CHK_NULL_RETURN(miItf);
+    CHK_NULL_RETURN(cmdBuffer);
+    CHK_NULL_RETURN(presSrc);
+
+    PMOS_CONTEXT pOsContext = osInterface->pOsContext;
+    CHK_NULL_RETURN(pOsContext);
+
+    uint32_t perfDataIndex = m_contextIndexMap[context];
+
+    switch (item)
+    {
+        case UMD_QUALITY_ITEM_SSEY:
+            offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, SSEY);
+            break;
+        case UMD_QUALITY_ITEM_SSEU:
+            offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, SSEU);
+            break;
+        case UMD_QUALITY_ITEM_SSEV:
+            offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, SSEV);
+            break;
+        case UMD_QUALITY_ITEM_MEAN_SSIM_YU:
+            offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, DWMeanSsimLayer1_YU);
+            break;
+        case UMD_QUALITY_ITEM_MEAN_SSIM_V:
+            offset = BASE_OF_NODE(perfDataIndex) + OFFSET_OF(PerfEntry, DWMeanSsimLayer1_V);
+            break;
+        default:
+            status = MOS_STATUS_INVALID_PARAMETER;
+            break;
+    }
+
+    if (status == MOS_STATUS_SUCCESS)
+    {
+        CHK_STATUS_RETURN(CopyMemData(miItf, cmdBuffer, pOsContext, presSrc, dwSrcOffset, offset));
+    }
+
+    return status;
+}
+
 MOS_STATUS MediaPerfProfiler::SavePerfData(MOS_INTERFACE *osInterface)
 {
     MOS_STATUS status = MOS_STATUS_SUCCESS;
@@ -643,7 +811,75 @@ MOS_STATUS MediaPerfProfiler::SavePerfData(MOS_INTERFACE *osInterface)
     PMOS_CONTEXT pOsContext = osInterface->pOsContext;
     CHK_NULL_RETURN(pOsContext);
 
-    if (m_perfDataIndexMap[pOsContext] > 0)
+    if (m_multiprocesssinglebin)
+    {
+        uint32_t        cnt                     = 0;
+        MOS_LOCK_PARAMS LockFlagsNoOverWrite    = {};
+
+        MOS_ZeroMemory(&LockFlagsNoOverWrite, sizeof(MOS_LOCK_PARAMS));
+        LockFlagsNoOverWrite.WriteOnly = 1;
+        LockFlagsNoOverWrite.NoOverWrite = 1;
+
+        if (m_perfDataCombined == nullptr)
+        {
+            m_perfDataCombinedSize  = 96;
+
+            for (auto iter = m_perfDataIndexMap.begin(); iter != m_perfDataIndexMap.end(); ++iter)
+            {
+                if (iter->second > 0)
+                {
+                    m_perfDataCombinedSize += BASE_OF_NODE(m_perfDataIndexMap[iter->first]) + 4;
+                    cnt += 1;
+                }
+            }
+
+            if (cnt == 0)
+            {
+                return status;
+            }
+
+            m_perfDataCombined = (uint32_t *)MOS_AllocAndZeroMemory(m_perfDataCombinedSize);
+            CHK_NULL_RETURN(m_perfDataCombined);
+
+            m_perfDataCombined[0] = 0x8086;
+            m_perfDataCombined[2] = m_perfDataCombinedSize - (cnt * 4);
+            m_perfDataCombined[3] = cnt;
+
+            m_perfDataCombinedOffset = 96 + (cnt * 4);
+        }
+
+        if (m_perfDataIndexMap[pOsContext] > 0)
+        {
+            uint8_t* pData = (uint8_t*)osInterface->pfnLockResource(
+                osInterface,
+                m_perfStoreBufferMap[pOsContext],
+                &LockFlagsNoOverWrite);
+
+            CHK_NULL_RETURN(pData);
+            MOS_SecureMemcpy(((uint8_t *)m_perfDataCombined) + m_perfDataCombinedOffset, BASE_OF_NODE(m_perfDataIndexMap[pOsContext]), pData, BASE_OF_NODE(m_perfDataIndexMap[pOsContext]));
+
+            osInterface->pfnUnlockResource(
+                osInterface,
+                m_perfStoreBufferMap[pOsContext]);
+
+            m_perfDataCombinedOffset += BASE_OF_NODE(m_perfDataIndexMap[pOsContext]);
+            m_perfDataCombined[24 + m_perfDataCombinedIndex] = BASE_OF_NODE(m_perfDataIndexMap[pOsContext]);
+            m_perfDataCombinedIndex ++;
+
+            if (m_perfDataCombinedOffset == m_perfDataCombinedSize)
+            {
+                MosUtilities::MosWriteFileFromPtr(m_outputFileName.c_str(), m_perfDataCombined, m_perfDataCombinedSize);
+                MOS_SafeFreeMemory(m_perfDataCombined);
+                m_perfDataCombined = nullptr;
+                m_perfDataCombinedIndex = 0;
+                m_perfDataCombinedOffset = 0;
+                m_perfDataCombinedSize = 0;
+            }
+        }
+
+        return status;
+    }
+    else if (m_perfDataIndexMap[pOsContext] > 0)
     {
         MOS_LOCK_PARAMS     LockFlagsNoOverWrite;
         MOS_ZeroMemory(&LockFlagsNoOverWrite, sizeof(MOS_LOCK_PARAMS));
@@ -670,6 +906,22 @@ MOS_STATUS MediaPerfProfiler::SavePerfData(MOS_INTERFACE *osInterface)
 
             MosUtilities::MosWriteFileFromPtr(outputFileName, pData, BASE_OF_NODE(m_perfDataIndexMap[pOsContext]));
         }
+        else if (m_mergeheader)
+        {
+            NodeHeader *header = reinterpret_cast<NodeHeader *>(pData);
+            char outputFileName[MOS_MAX_PATH_LENGTH + 1];
+            MOS_SecureStringPrint(outputFileName, MOS_MAX_PATH_LENGTH + 1, MOS_MAX_PATH_LENGTH + 1, "%s-header%u.bin", m_outputFileName.c_str(), *reinterpret_cast<uint32_t*>(header));
+            HANDLE hFile = nullptr;
+            if (MosUtilities::MosCreateFile(&hFile, outputFileName, 0) != MOS_STATUS_SUCCESS)
+            {
+                MosUtilities::MosWriteFileFromPtr(outputFileName, pData, BASE_OF_NODE(m_perfDataIndexMap[pOsContext]));
+            }
+            else
+            {
+                MosUtilities::MosCloseHandle(hFile);
+                MosUtilities::MosAppendFileFromPtr(outputFileName, pData + sizeof(NodeHeader), BASE_OF_NODE(m_perfDataIndexMap[pOsContext]) - sizeof(NodeHeader));
+            }
+        }
         else
         {
             MosUtilities::MosWriteFileFromPtr(m_outputFileName.c_str(), pData, BASE_OF_NODE(m_perfDataIndexMap[pOsContext]));
@@ -720,6 +972,12 @@ PerfGPUNode MediaPerfProfiler::GpuContextToGpuNode(MOS_GPU_CONTEXT context)
         case MOS_GPU_CONTEXT_VEBOX2:
             node = PERF_GPU_NODE_VE;
             break;
+        case MOS_GPU_CONTEXT_BLT:
+            node = PERF_GPU_NODE_BLT;
+            break;
+        case MOS_GPU_CONTEXT_TEE:
+            node = PERF_GPU_NODE_TEE;
+            break;
         default:
             node = PERF_GPU_NODE_UNKNOW;
             break;
@@ -759,4 +1017,4 @@ bool MediaPerfProfiler::IsPerfModeWidthMemInfo(uint32_t *regs)
     }
 
     return ret;
-}
\ No newline at end of file
+}
