@@ -169,6 +169,39 @@ MOS_STATUS SwFilterSubPipe::AddSwFilterUnordered(SwFilter *swFilter)
     return m_UnorderedFilters.AddSwFilter(swFilter);
 }
 
+MOS_STATUS SwFilterSubPipe::GetAiSwFilter(SwFilterAiBase *&swAiFilter)
+{
+    SwFilterAiBase *aiFilter = nullptr;
+    swAiFilter               = nullptr;
+    for (SwFilterSet*& swFilterSet : m_OrderedFilters)
+    {
+        if (swFilterSet)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(swFilterSet->GetAiSwFilter(aiFilter));
+            if (aiFilter)
+            {
+                if (swAiFilter)
+                {
+                    VP_PUBLIC_ASSERTMESSAGE("Only one AI Sw Filter is allowed in one SwFilterSubPipe. More than one is found. The last one is in ordered filters. Feature Types: %d and %d", swAiFilter->GetFeatureType(), aiFilter->GetFeatureType());
+                    VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+                }
+                swAiFilter = aiFilter;
+            }
+        }
+    }
+    VP_PUBLIC_CHK_STATUS_RETURN(m_UnorderedFilters.GetAiSwFilter(aiFilter));
+    if (aiFilter)
+    {
+        if (swAiFilter)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("Only one AI Sw Filter is allowed in one SwFilterSubPipe. More than one is found. The last one is in unordered filters. Feature Types: %d and %d", swAiFilter->GetFeatureType(), aiFilter->GetFeatureType());
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+        }
+        swAiFilter = aiFilter;
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
 /****************************************************************************************************/
 /*                                      SwFilterPipe                                                */
 /****************************************************************************************************/
@@ -501,7 +534,7 @@ MOS_STATUS SwFilterPipe::ConfigFeaturesToPipe(VP_PIPELINE_PARAMS &params, Featur
             {
                 VP_PUBLIC_CHK_STATUS_RETURN(AddSwFilterUnordered(swFilter, isInputPipe, pipeIndex));
                 MT_LOG4(MT_VP_HAL_SWWFILTER_ADD, MT_NORMAL, MT_VP_HAL_PIPE_ISINPUT, isInputPipe, MT_VP_HAL_PIPE_INDEX, pipeIndex, 
-                    MT_VP_HAL_FEATUERTYPE, swFilter->GetFeatureType(), MT_VP_HAL_ENGINECAPS, swFilter->GetFilterEngineCaps().value);
+                    MT_VP_HAL_FEATUERTYPE, swFilter->GetFeatureType(), MT_VP_HAL_ENGINECAPS, int64_t(swFilter->GetFilterEngineCaps().value));
             }
         }
     }
@@ -589,6 +622,7 @@ MOS_STATUS SwFilterPipe::UpdateFeatures(bool isInputPipe, uint32_t pipeIndex, VP
                 auto handler = m_vpInterface.GetSwFilterHandler(FeatureTypeCsc);
                 VP_PUBLIC_CHK_NULL_RETURN(handler);
                 SwFilterCsc* swfilter = dynamic_cast<SwFilterCsc *>(handler->CreateSwFilter());
+                VP_PUBLIC_CHK_NULL_RETURN(swfilter);
                 swfilter->Configure(inputSurf, outputSurf, *caps);
                 inputPipe->AddSwFilterUnordered(swfilter);
             }
@@ -731,7 +765,7 @@ MOS_STATUS SwFilterPipe::AddSwFilterUnordered(SwFilter *swFilter, bool isInputPi
 
     if (nullptr == pSubPipe && !isInputPipe)
     {
-        auto& pipes = isInputPipe ? m_InputPipes : m_OutputPipes;
+        auto& pipes = m_OutputPipes;
         SwFilterSubPipe *pipe = MOS_New(SwFilterSubPipe);
         VP_PUBLIC_CHK_NULL_RETURN(pipe);
         if ((size_t)index <= pipes.size())
@@ -1152,17 +1186,50 @@ bool SwFilterPipe::IsAllInputPipeSurfaceFeatureEmpty(std::vector<int> &layerInde
     return true;
 }
 
+MOS_STATUS SwFilterPipe::QuerySwAiFilter(bool &containsSwAiFilter)
+{
+    containsSwAiFilter = false;
+    for (SwFilterSubPipe*& inputPipe : m_InputPipes)
+    {
+        SwFilterAiBase* swAiFilter = nullptr;
+        if (inputPipe)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(inputPipe->GetAiSwFilter(swAiFilter));
+            if (swAiFilter)
+            {
+                containsSwAiFilter = true;
+                return MOS_STATUS_SUCCESS;
+            }
+        }
+    }
+    for (SwFilterSubPipe *&outputPipe : m_OutputPipes)
+    {
+        SwFilterAiBase *swAiFilter = nullptr;
+        if (outputPipe)
+        {
+            VP_PUBLIC_CHK_STATUS_RETURN(outputPipe->GetAiSwFilter(swAiFilter));
+            if (swAiFilter)
+            {
+                containsSwAiFilter = true;
+                return MOS_STATUS_SUCCESS;
+            }
+        }
+    }
+    return MOS_STATUS_SUCCESS;
+}
+
 MOS_STATUS SwFilterPipe::AddRTLog()
 {
     VP_FUNC_CALL();
 
     uint32_t i = 0;
-
+    MT_LOG1(MT_VP_FEATURE_GRAPH_GET_RENDERTARGETTYPE, MT_NORMAL, MT_VP_FEATURE_GRAPH_RENDERTARGETTYPE, GetRenderTargetType())
+    MT_LOG1(MT_VP_FEATURE_GRAPH_INPUTSWFILTER, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)m_InputPipes.size());
     for (i = 0; i < m_InputPipes.size(); ++i)
     {
         VP_PUBLIC_CHK_STATUS_RETURN(AddFeatureGraphRTLog(true, i));
     }
-
+    MT_LOG1(MT_VP_FEATURE_GRAPH_OUTPUTSWFILTER, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT, (int64_t)m_OutputPipes.size());
     for (i = 0; i < m_OutputPipes.size(); ++i)
     {
         VP_PUBLIC_CHK_STATUS_RETURN(AddFeatureGraphRTLog(false, i));
@@ -1182,10 +1249,50 @@ MOS_STATUS SwFilterPipe::AddFeatureGraphRTLog(bool isInputPipe, uint32_t pipeInd
     // Input surface/pipe may be empty for some feature.
     if (isInputPipe)
     {
+        MT_LOG7(MT_VP_FEATURE_GRAPH_INPUT_SURFACE_INFO, MT_NORMAL, MT_VP_FEATURE_GRAPH_SURFACE_WIDTH, m_InputSurfaces[pipeIndex]->osSurface->dwWidth, MT_VP_FEATURE_GRAPH_SURFACE_HEIGHT, m_InputSurfaces[pipeIndex]->osSurface->dwHeight, MT_VP_FEATURE_GRAPH_SURFACE_PITCH, m_InputSurfaces[pipeIndex]->osSurface->dwPitch, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_LEFT, m_InputSurfaces[pipeIndex]->rcSrc.left, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_TOP, m_InputSurfaces[pipeIndex]->rcSrc.top, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_RIGHT, m_InputSurfaces[pipeIndex]->rcSrc.right, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_BOTTOM, m_InputSurfaces[pipeIndex]->rcSrc.bottom);
+        MT_LOG7(MT_VP_FEATURE_GRAPH_INPUT_SURFACE_INFO, MT_NORMAL, MT_VP_FEATURE_GRAPH_SURFACE_COLORSPACE, m_InputSurfaces[pipeIndex]->ColorSpace, MT_VP_FEATURE_GRAPH_SURFACE_FORMAT, m_InputSurfaces[pipeIndex]->osSurface->Format, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_LEFT, m_InputSurfaces[pipeIndex]->rcDst.left, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_TOP, m_InputSurfaces[pipeIndex]->rcDst.top, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT, m_InputSurfaces[pipeIndex]->rcDst.right, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM, m_InputSurfaces[pipeIndex]->rcDst.bottom, MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE, static_cast<int64_t>(m_InputSurfaces[pipeIndex]->GetAllocationHandle(m_vpInterface.GetHwInterface()->m_osInterface)));
+        VP_PUBLIC_NORMALMESSAGE(
+            "Feature Graph: Input Surface: dwWidth %d, dwHeight %d, dwPitch %d, ColorSpace %d, Format %d, \
+            rcSrc.left %d, rcSrc.top %d, rcSrc.right %d, rcSrc.bottom %d, \
+            rcDst.left %d, rcDst.top %d, rcDst.right %d, rcDst.bottom %d, surface allocationhandle %d",
+            m_InputSurfaces[pipeIndex]->osSurface->dwWidth,
+            m_InputSurfaces[pipeIndex]->osSurface->dwHeight,
+            m_InputSurfaces[pipeIndex]->osSurface->dwPitch,
+            m_InputSurfaces[pipeIndex]->ColorSpace,
+            m_InputSurfaces[pipeIndex]->osSurface->Format,
+            m_InputSurfaces[pipeIndex]->rcSrc.left,
+            m_InputSurfaces[pipeIndex]->rcSrc.top,
+            m_InputSurfaces[pipeIndex]->rcSrc.right,
+            m_InputSurfaces[pipeIndex]->rcSrc.bottom,
+            m_InputSurfaces[pipeIndex]->rcDst.left,
+            m_InputSurfaces[pipeIndex]->rcDst.top,
+            m_InputSurfaces[pipeIndex]->rcDst.right,
+            m_InputSurfaces[pipeIndex]->rcDst.bottom,
+            m_InputSurfaces[pipeIndex]->GetAllocationHandle(m_vpInterface.GetHwInterface()->m_osInterface));
         VP_PUBLIC_CHK_STATUS_RETURN(inputPipe->AddFeatureGraphRTLog());
     }
     else
     {
+        MT_LOG7(MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO, MT_NORMAL, MT_VP_FEATURE_GRAPH_SURFACE_WIDTH, m_OutputSurfaces[pipeIndex]->osSurface->dwWidth, MT_VP_FEATURE_GRAPH_SURFACE_HEIGHT, m_OutputSurfaces[pipeIndex]->osSurface->dwHeight, MT_VP_FEATURE_GRAPH_SURFACE_PITCH, m_OutputSurfaces[pipeIndex]->osSurface->dwPitch, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_LEFT, m_OutputSurfaces[pipeIndex]->rcSrc.left, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_TOP, m_OutputSurfaces[pipeIndex]->rcSrc.top, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_RIGHT, m_OutputSurfaces[pipeIndex]->rcSrc.right, MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_BOTTOM, m_OutputSurfaces[pipeIndex]->rcSrc.bottom);
+        MT_LOG7(MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO, MT_NORMAL, MT_VP_FEATURE_GRAPH_SURFACE_COLORSPACE, m_OutputSurfaces[pipeIndex]->ColorSpace, MT_VP_FEATURE_GRAPH_SURFACE_FORMAT, m_OutputSurfaces[pipeIndex]->osSurface->Format, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_LEFT, m_OutputSurfaces[pipeIndex]->rcDst.left, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_TOP, m_OutputSurfaces[pipeIndex]->rcDst.top, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT, m_OutputSurfaces[pipeIndex]->rcDst.right, MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM, m_OutputSurfaces[pipeIndex]->rcDst.bottom, MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE, static_cast<int64_t>(m_OutputSurfaces[pipeIndex]->GetAllocationHandle(m_vpInterface.GetHwInterface()->m_osInterface)));
+        VP_PUBLIC_NORMALMESSAGE(
+            "Feature Graph: Output Surface: dwWidth %d, dwHeight %d, dwPitch %d, ColorSpace %d, Format %d, \
+            rcSrc.left %d, rcSrc.top %d, rcSrc.right %d, rcSrc.bottom %d, \
+            rcDst.left %d, rcDst.top %d, rcDst.right %d, rcDst.bottom %d, surface allocationhandle %d",
+            m_OutputSurfaces[pipeIndex]->osSurface->dwWidth,
+            m_OutputSurfaces[pipeIndex]->osSurface->dwHeight,
+            m_OutputSurfaces[pipeIndex]->osSurface->dwPitch,
+            m_OutputSurfaces[pipeIndex]->ColorSpace,
+            m_OutputSurfaces[pipeIndex]->osSurface->Format,
+            m_OutputSurfaces[pipeIndex]->rcSrc.left,
+            m_OutputSurfaces[pipeIndex]->rcSrc.top,
+            m_OutputSurfaces[pipeIndex]->rcSrc.right,
+            m_OutputSurfaces[pipeIndex]->rcSrc.bottom,
+            m_OutputSurfaces[pipeIndex]->rcDst.left,
+            m_OutputSurfaces[pipeIndex]->rcDst.top,
+            m_OutputSurfaces[pipeIndex]->rcDst.right,
+            m_OutputSurfaces[pipeIndex]->rcDst.bottom,
+            m_OutputSurfaces[pipeIndex]->GetAllocationHandle(m_vpInterface.GetHwInterface()->m_osInterface));
         VP_PUBLIC_CHK_STATUS_RETURN(outputPipe->AddFeatureGraphRTLog());
     }
 
