@@ -44,6 +44,7 @@ namespace vp
 #define MAX_LAYER_COUNT VPHAL_MAX_SOURCES
 
 class VpInterface;
+class VpPipelineParamFactory;
 
 struct FeatureSet
 {
@@ -104,6 +105,8 @@ public:
         return IsEmpty() || RenderTargetTypeParameter == GetRenderTargetType();
     }
 
+    MOS_STATUS GetAiSwFilter(SwFilterAiBase *&swAiFilter);
+
 private:
     std::vector<SwFilterSet *> m_OrderedFilters;    // For features in featureRule
     SwFilterSet m_UnorderedFilters;                 // For features not in featureRule
@@ -174,6 +177,7 @@ public:
     bool IsAllInputPipeEmpty();
     bool IsAllInputPipeSurfaceFeatureEmpty();
     bool IsAllInputPipeSurfaceFeatureEmpty(std::vector<int> &layerIndexes);
+    MOS_STATUS  QuerySwAiFilter(bool &containsSwAiFilter);
 
     VP_SURFACE_SETTING &GetSurfacesSetting()
     {
@@ -204,7 +208,8 @@ public:
 
     RenderTargetType GetRenderTargetType()
     {
-        for (auto subpipe : m_InputPipes)
+        std::vector<SwFilterSubPipe *> &pipes = (m_InputPipes.size() == 0) ? m_OutputPipes : m_InputPipes;
+        for (auto subpipe : pipes)
         {
             if (subpipe)
             {
