@@ -25,12 +25,9 @@
 //!           this file is for the base interface which is shared by all Procamp in driver.
 //!
 #include "vp_procamp_filter.h"
-#include "vp_vebox_cmd_packet.h"
+#include "vp_vebox_cmd_packet_base.h"
 #include "hw_filter.h"
 #include "sw_filter_pipe.h"
-#ifndef ENABLE_VP_SOFTLET_BUILD
-#include "vp_vebox_cmd_packet_legacy.h"
-#endif
 
 namespace vp {
 VpProcampFilter::VpProcampFilter(PVP_MHWINTERFACE vpMhwInterface) :
@@ -201,18 +198,11 @@ bool VpVeboxProcampParameter::SetPacketParam(VpCmdPacket *pPacket)
         return false;
     }
 
-    VpVeboxCmdPacket *packet = dynamic_cast<VpVeboxCmdPacket *>(pPacket);
+    VpVeboxCmdPacketBase *packet = dynamic_cast<VpVeboxCmdPacketBase *>(pPacket);
     if (packet)
     {
         return MOS_SUCCEEDED(packet->SetProcampParams(pParams));
     }
-#ifndef ENABLE_VP_SOFTLET_BUILD
-    VpVeboxCmdPacketLegacy *packetLegacy = dynamic_cast<VpVeboxCmdPacketLegacy *>(pPacket);
-    if (packetLegacy)
-    {
-        return MOS_SUCCEEDED(packetLegacy->SetProcampParams(pParams));
-    }
-#endif
 
     VP_PUBLIC_ASSERTMESSAGE("Invalid packet for Vebox procamp");
     return false;
