@@ -71,7 +71,7 @@ protected:
     VpKernelSet         *m_kernelSet = nullptr;
     VP_PACKET_SHARED_CONTEXT *m_packetSharedContext = nullptr;
 
-MEDIA_CLASS_DEFINE_END(PacketFactory)
+MEDIA_CLASS_DEFINE_END(vp__PacketFactory)
 };
 
 class PacketPipe
@@ -92,6 +92,16 @@ public:
         return m_veboxFeatureInuse;
     }
 
+    uint32_t PacketNum()
+    {
+        return m_Pipe.size();
+    }
+
+    VpCmdPacket *GetPacket(uint32_t idx)
+    {
+        return idx < m_Pipe.size() ? m_Pipe[idx] : nullptr;
+    }
+
     static MOS_STATUS SwitchContext(PacketType type, MediaScalability *&scalability, MediaContext *mediaContext, bool bEnableVirtualEngine, uint8_t numVebox);
 
 private:
@@ -103,7 +113,7 @@ private:
     VPHAL_OUTPUT_PIPE_MODE m_outputPipeMode = VPHAL_OUTPUT_PIPE_MODE_INVALID;
     bool m_veboxFeatureInuse = false;
 
-MEDIA_CLASS_DEFINE_END(PacketPipe)
+MEDIA_CLASS_DEFINE_END(vp__PacketPipe)
 };
 
 class PacketPipeFactory
@@ -118,7 +128,7 @@ private:
     PacketFactory &m_pPacketFactory;
     std::vector<PacketPipe *> m_Pool;
 
-MEDIA_CLASS_DEFINE_END(PacketPipeFactory)
+MEDIA_CLASS_DEFINE_END(vp__PacketPipeFactory)
 };
 
 }
