@@ -99,6 +99,7 @@ typedef struct _KERNEL_PARAMS
     bool                         flushL1;
     KERNEL_TUNING_PARAMS         kernelTuningParams;
     KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
+    std::string                  kernelName;
 } KERNEL_PARAMS;
 
 struct MEDIA_OBJECT_KA2_INLINE_DATA
@@ -609,6 +610,8 @@ protected:
     std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
     std ::vector<MHW_INLINE_DATA_PARAMS>                    m_inlineDataParams = {};
 
+    KERNEL_ARG_INDEX_SURFACE_MAP                            m_argIndexSurfMap = {};
+
 MEDIA_CLASS_DEFINE_END(vp__VpRenderKernelObj)
 };
 }
