@@ -44,6 +44,16 @@ VpPipeline::VpPipeline(PMOS_INTERFACE osInterface) :
 
 VpPipeline::~VpPipeline()
 {
+#if (_DEBUG || _RELEASE_INTERNAL)
+    if (m_reportOnceFlag)
+    {
+        ReportUserSettingForDebug(
+            m_userSettingPtr,
+            __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K_REPORT,
+            0,
+            MediaUserSetting::Group::Sequence);
+    }
+#endif
     // Delete m_featureManager before m_resourceManager, since
     // m_resourceManager is referenced by m_featureManager.
     MOS_Delete(m_featureManager);
@@ -218,33 +228,61 @@ MOS_STATUS VpPipeline::UserFeatureReport()
             {
                 m_reporting->GetFeatures().rtOldCacheSetting = (uint8_t)(m_vpMhwInterface.m_renderHal->oldCacheSettingForTargetSurface);
             }
-            if (m_reporting->GetFeatures().isL03DLut)
+            if (m_reporting->GetFeatures().isOcl3DLut)
             {
-                VP_PUBLIC_NORMALMESSAGE("VP L0 3DLut Enabled");
+                VP_PUBLIC_NORMALMESSAGE("VP OCL 3DLut Enabled");
                 ReportUserSettingForDebug(
                     m_userSettingPtr,
-                    __MEDIA_USER_FEATURE_VALUE_VP_L0_3DLUT_ENABLED,
+                    __MEDIA_USER_FEATURE_VALUE_VP_OCL_3DLUT_ENABLED,
                     1,
                     MediaUserSetting::Group::Sequence);
             }
 #endif
         }
 #if (_DEBUG || _RELEASE_INTERNAL)
-        if (m_reporting->GetFeatures().isL0FC)
+        if (m_reporting->GetFeatures().isOclFC)
         {
-            VP_PUBLIC_NORMALMESSAGE("VP L0 FC Enabled");
+            VP_PUBLIC_NORMALMESSAGE("VP OCL FC Supported");
             ReportUserSettingForDebug(
                 m_userSettingPtr,
-                __MEDIA_USER_FEATURE_VALUE_VP_L0_FC_ENABLED,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_SUPPORTED,
                 1,
                 MediaUserSetting::Group::Sequence);
 
             ReportUserSettingForDebug(
                 m_userSettingPtr,
-                __MEDIA_USER_FEATURE_VALUE_VP_L0_FC_REPORT,
-                m_reporting->GetFeatures().diffLogL0FC,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_FEATURE_REPORT,
+                m_reporting->GetFeatures().featureLogOclFC,
                 MediaUserSetting::Group::Sequence);
+
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_REPORT,
+                m_reporting->GetFeatures().diffLogOclFC,
+                MediaUserSetting::Group::Sequence);
+
+            if (m_reporting->GetFeatures().isLegacyFCInUse)
+            {
+                ReportUserSettingForDebug(
+                    m_userSettingPtr,
+                    __MEDIA_USER_FEATURE_VALUE_VP_LEGACY_FC_IN_USE,
+                    1,
+                    MediaUserSetting::Group::Sequence);
+                m_reporting->GetFeatures().isLegacyFCInUse = false;
+            }
         }
+
+        if (m_reportOnceFlag && m_reporting->GetFeatures().fallbackScalingToRender8K)
+        {
+            ReportUserSettingForDebug(
+                m_userSettingPtr,
+                __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K_REPORT,
+                1,
+                MediaUserSetting::Group::Sequence);
+            m_reporting->GetFeatures().fallbackScalingToRender8K = false;
+            m_reportOnceFlag                                     = false;
+        }
+        
 #endif
 
         m_reporting->GetFeatures().VPApogeios = m_currentFrameAPGEnabled;
@@ -379,13 +417,15 @@ MOS_STATUS VpPipeline::Init(void *mhwInterface)
             VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(VP_PIPELINE_PACKET_VEBOX, m_scalability,
                 m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
         }
-
-        bool computeContextEnabled = m_userFeatureControl->IsComputeContextEnabled();
-        auto packetId              = computeContextEnabled ? VP_PIPELINE_PACKET_COMPUTE : VP_PIPELINE_PACKET_RENDER;
-        VP_PUBLIC_NORMALMESSAGE("Create GpuContext for Compute/Render (PacketId: %d).", packetId);
-        VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(packetId, m_scalability,
-            m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
-
+        // If the environment is SA media in which there are no GT IP, we could not create/use Render or Compute GPU context.
+        if (!(m_skuTable && MEDIA_IS_SKU(m_skuTable, FtrDisableGtIpSubmissions)))
+        {
+            bool computeContextEnabled = m_userFeatureControl->IsComputeContextEnabled();
+            auto packetId              = computeContextEnabled ? VP_PIPELINE_PACKET_COMPUTE : VP_PIPELINE_PACKET_RENDER;
+            VP_PUBLIC_NORMALMESSAGE("Create GpuContext for Compute/Render (PacketId: %d).", packetId);
+            VP_PUBLIC_CHK_STATUS_RETURN(PacketPipe::SwitchContext(packetId, m_scalability,
+                m_mediaContext, MOS_VE_SUPPORTED(m_osInterface), m_numVebox));
+        }
         // create SinglePipe GpuContext for multi Vebox system to avoid first frame long latency issue
         if (m_numVebox > 1 && !(m_vpSettings && m_vpSettings->clearVideoViewMode))
         {
