@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2023, Intel Corporation
+* Copyright (c) 2020-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -75,12 +75,29 @@ MOS_STATUS VpScalabilityMultiPipeNext::AllocateSemaphore()
     allocParamsForBufferLinear.dwBytes  = VP_SEMAPHORE_COUNT * sizeof(uint32_t);
     allocParamsForBufferLinear.pBufName = "Sync All Pipes SemaphoreMemory";
 
-    memset(&m_resSemaphoreAllPipes, 0, sizeof(MOS_RESOURCE));
-    SCALABILITY_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
-                                              m_osInterface,
-                                              &allocParamsForBufferLinear,
-                                              &m_resSemaphoreAllPipes),
-        "Cannot create HW semaphore for scalability all pipes sync.");
+    for (uint32_t i = 0; i < 2; i++)
+    {
+        memset(&m_resSemaphoreAllPipes[i], 0, sizeof(MOS_RESOURCE));
+        SCALABILITY_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
+                                                  m_osInterface,
+                                                  &allocParamsForBufferLinear,
+                                                  &m_resSemaphoreAllPipes[i]),
+            "Cannot create HW semaphore for scalability all pipes sync.");
+
+        MOS_LOCK_PARAMS lockFlagsWriteOnly;
+        MOS_ZeroMemory(&lockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
+        lockFlagsWriteOnly.WriteOnly = 1;
+
+        uint32_t *data = (uint32_t *)m_osInterface->pfnLockResource(
+            m_osInterface,
+            &m_resSemaphoreAllPipes[i],
+            &lockFlagsWriteOnly);
+        SCALABILITY_CHK_NULL_RETURN(data);
+        MOS_ZeroMemory(data, VP_SEMAPHORE_COUNT * sizeof(uint32_t));
+        SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnUnlockResource(
+            m_osInterface,
+            &m_resSemaphoreAllPipes[i]));
+    }
     memset(&m_resSemaphoreOnePipeWait, 0, sizeof(MOS_RESOURCE));
     SCALABILITY_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
                                               m_osInterface,
@@ -109,7 +126,6 @@ MOS_STATUS VpScalabilityMultiPipeNext::Initialize(const MediaScalabilityOption &
     VpScalabilityOption *vpScalabilityOption = MOS_New(VpScalabilityOption, (const VpScalabilityOption &)option);
     SCALABILITY_CHK_NULL_RETURN(vpScalabilityOption);
     m_scalabilityOption = vpScalabilityOption;
-
     if (m_hwInterface->m_bIsMediaSfcInterfaceInUse)
     {
         m_frameTrackingEnabled = false;
@@ -129,7 +145,7 @@ MOS_STATUS VpScalabilityMultiPipeNext::Initialize(const MediaScalabilityOption &
     veInitParms.ucMaxNumPipesInUse             = vpScalabilityOption->GetMaxMultiPipeNum();
     veInitParms.ucMaxNumOfSdryCmdBufInOneFrame = veInitParms.ucMaxNumPipesInUse;
 
-    if (m_osInterface->apoMosEnabled)
+    if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime)
     {
         SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState);
         m_osInterface->osStreamState->component = COMPONENT_VPCommon;
@@ -138,7 +154,17 @@ MOS_STATUS VpScalabilityMultiPipeNext::Initialize(const MediaScalabilityOption &
         SCALABILITY_CHK_NULL_RETURN(m_veState);
         SCALABILITY_CHK_NULL_RETURN(m_veHitParams);
     }
-
+    else
+    {
+        SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnVirtualEngineInit(m_osInterface, &m_veHitParams, veInitParms));
+        m_veInterface = m_osInterface->pVEInterf;
+        SCALABILITY_CHK_NULL_RETURN(m_veInterface);
+        if (m_veInterface->pfnVEGetHintParams != nullptr)
+        {
+            SCALABILITY_CHK_NULL_RETURN(m_veHitParams);
+        }
+    }
+    
     m_pipeNum = m_scalabilityOption->GetNumPipe();
     m_pipeIndexForSubmit = m_pipeNum;
 
@@ -151,12 +177,23 @@ MOS_STATUS VpScalabilityMultiPipeNext::Initialize(const MediaScalabilityOption &
 
 #if (_DEBUG || _RELEASE_INTERNAL)
     if (m_osInterface->bEnableDbgOvrdInVE)
-    {
-        for (uint32_t i = 0; i < m_osInterface->pfnGetVeEngineCount(m_osInterface->osStreamState); i++)
+    {   
+        if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime)
         {
-            gpuCtxCreateOption->EngineInstance[i] =
-                m_osInterface->pfnGetEngineLogicIdByIdx(m_osInterface->osStreamState, i);
+            for (uint32_t i = 0; i < m_osInterface->pfnGetVeEngineCount(m_osInterface->osStreamState); i++)
+            {
+                gpuCtxCreateOption->EngineInstance[i] =
+                    m_osInterface->pfnGetEngineLogicIdByIdx(m_osInterface->osStreamState, i);
+            }
         }
+        else
+        {
+            for (uint32_t i = 0; i < m_veInterface->ucEngineCount; i++)
+            {
+                gpuCtxCreateOption->EngineInstance[i] = m_veInterface->EngineLogicId[i];
+            }
+        }
+        
     }
 #endif
     m_gpuCtxCreateOption = (PMOS_GPUCTX_CREATOPTIONS)(gpuCtxCreateOption);
@@ -187,11 +224,8 @@ MOS_STATUS VpScalabilityMultiPipeNext::GetGpuCtxCreationOption(MOS_GPUCTX_CREATO
 MOS_STATUS VpScalabilityMultiPipeNext::Destroy()
 {
     VP_FUNC_CALL();
-
     SCALABILITY_FUNCTION_ENTER;
-
     SCALABILITY_CHK_STATUS_RETURN(MediaScalability::Destroy());
-
     if (m_gpuCtxCreateOption)
     {
         MOS_Delete(m_gpuCtxCreateOption);
@@ -200,8 +234,28 @@ MOS_STATUS VpScalabilityMultiPipeNext::Destroy()
     {
         MOS_Delete(m_scalabilityOption);
     }
-
-    m_osInterface->pfnFreeResource(m_osInterface, &m_resSemaphoreAllPipes);
+    
+    if (m_veInterface)
+    {
+        if (m_veInterface->pfnVEDestroy)
+        {
+            m_veInterface->pfnVEDestroy(m_veInterface);
+        }
+        MOS_FreeMemAndSetNull(m_veInterface);
+    }
+    else
+    {
+        if (!m_osInterface->apoMosEnabled && !m_osInterface->apoMosForLegacyRuntime)
+        {
+            if (MOS_VE_SUPPORTED(m_osInterface))
+            {
+                SCALABILITY_CHK_NULL_RETURN(m_veInterface);
+            }
+        }
+    }
+    
+    m_osInterface->pfnFreeResource(m_osInterface, &m_resSemaphoreAllPipes[0]);
+    m_osInterface->pfnFreeResource(m_osInterface, &m_resSemaphoreAllPipes[1]);
     m_osInterface->pfnFreeResource(m_osInterface, &m_resSemaphoreOnePipeWait);
 
     return MOS_STATUS_SUCCESS;
@@ -330,16 +384,27 @@ MOS_STATUS VpScalabilityMultiPipeNext::GetCmdBuffer(PMOS_COMMAND_BUFFER cmdBuffe
     {
         m_osInterface->pfnGetCommandBuffer(m_osInterface, &m_secondaryCmdBuffers[bufIdx], bufIdxPlus1);
     }
-
-    int32_t submissionType = IsFirstPipe() ? SUBMISSION_TYPE_MULTI_PIPE_MASTER : SUBMISSION_TYPE_MULTI_PIPE_SLAVE;
-    if (IsLastPipe())
+    
+    if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime)
     {
-        submissionType |= SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE;
+        int32_t submissionType = IsFirstPipe() ? SUBMISSION_TYPE_MULTI_PIPE_MASTER : SUBMISSION_TYPE_MULTI_PIPE_SLAVE;
+        if (IsLastPipe())
+        {
+            submissionType |= SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE;
+        }
+        SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState);
+        SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState->virtualEngineInterface);
+        SCALABILITY_CHK_STATUS_RETURN(m_osInterface->osStreamState->virtualEngineInterface->SetSubmissionType(&(m_secondaryCmdBuffers[bufIdx]), submissionType));
+    }
+    else
+    {
+        m_secondaryCmdBuffers[bufIdx].iSubmissionType =
+            IsFirstPipe() ? SUBMISSION_TYPE_MULTI_PIPE_MASTER : SUBMISSION_TYPE_MULTI_PIPE_SLAVE;
+        if (IsLastPipe())
+        {
+            m_secondaryCmdBuffers[bufIdx].iSubmissionType |= SUBMISSION_TYPE_MULTI_PIPE_FLAGS_LAST_PIPE;
+        }
     }
-    SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState);
-    SCALABILITY_CHK_NULL_RETURN(m_osInterface->osStreamState->virtualEngineInterface);
-    SCALABILITY_CHK_STATUS_RETURN(m_osInterface->osStreamState->virtualEngineInterface->SetSubmissionType(&(m_secondaryCmdBuffers[bufIdx]), submissionType));
-
     *cmdBuffer = m_secondaryCmdBuffers[bufIdx];
     m_secondaryCmdBuffersReturned[bufIdx] = false;
 
@@ -391,7 +456,7 @@ MOS_STATUS VpScalabilityMultiPipeNext::SetHintParams()
     SCALABILITY_FUNCTION_ENTER;
 
     SCALABILITY_CHK_NULL_RETURN(m_osInterface);
-
+    
     VpScalabilityOption *vpScalabilityOption = dynamic_cast<VpScalabilityOption *>(m_scalabilityOption);
     SCALABILITY_CHK_NULL_RETURN(vpScalabilityOption);
 
@@ -434,9 +499,12 @@ MOS_STATUS VpScalabilityMultiPipeNext::SubmitCmdBuffer(PMOS_COMMAND_BUFFER cmdBu
     SCALABILITY_CHK_NULL_RETURN(m_osInterface);
 
     m_attrReady = false;
-
-    SCALABILITY_CHK_STATUS_RETURN(SetHintParams());
-    SCALABILITY_CHK_STATUS_RETURN(PopulateHintParams(&m_primaryCmdBuffer));
+    
+    if (m_osInterface->apoMosEnabled || m_osInterface->apoMosForLegacyRuntime|| (m_veInterface && m_veInterface->pfnVESetHintParams != nullptr))
+    {
+        SCALABILITY_CHK_STATUS_RETURN(SetHintParams());
+        SCALABILITY_CHK_STATUS_RETURN(PopulateHintParams(&m_primaryCmdBuffer));
+    }
 
 #if MOS_COMMAND_BUFFER_DUMP_SUPPORTED
     if (m_osInterface->bDumpCommandBuffer)
@@ -470,30 +538,41 @@ MOS_STATUS VpScalabilityMultiPipeNext::SyncAllPipes(PMOS_COMMAND_BUFFER cmdBuffe
     SCALABILITY_FUNCTION_ENTER;
     SCALABILITY_CHK_NULL_RETURN(cmdBuffer);
     SCALABILITY_CHK_NULL_RETURN(m_hwInterface);
-    SCALABILITY_ASSERT(m_semaphoreAllPipesIndex < VP_SEMAPHORE_COUNT);
-    SCALABILITY_ASSERT(!Mos_ResourceIsNull(&m_resSemaphoreAllPipes));
+    SCALABILITY_ASSERT(m_semaphoreAllPipesIndex < VP_SEMAPHORE_COUNT * 2);
+    SCALABILITY_ASSERT(!Mos_ResourceIsNull(&m_resSemaphoreAllPipes[0]));
+    SCALABILITY_ASSERT(!Mos_ResourceIsNull(&m_resSemaphoreAllPipes[1]));
+
+    // use two Semaphore Buffer repeatly to avoid waiting for lock, use the first Semaphore Buffer when m_semaphoreAllPipesIndex < VP_SEMAPHORE_COUNT.
+    // when the m_semaphoreAllPipesIndex >= VP_SEMAPHORE_COUNT, switch to the second Semaphore Buffer
+    uint32_t semaphoreIndex = (m_semaphoreAllPipesIndex >= VP_SEMAPHORE_COUNT) ? 1 : 0;
 
     if (m_semaphoreAllPipesPhase == 0)
     {
         if (m_currentPipe == 0)
         {
-            char ocaMsg[] = "VEBOX0 SCALABILITY";
-            HalOcaInterfaceNext::TraceMessage(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, ocaMsg, sizeof(ocaMsg));
+            std::stringstream ss;
+            ss << "VEBOX0 SCALABILITY. semaphoreIndex 0x" << std::hex << semaphoreIndex << " m_semaphoreAllPipesIndex 0x"
+                << std::hex  << m_semaphoreAllPipesIndex ;
+            std::string ocaMsg = ss.str();
+            HalOcaInterfaceNext::TraceMessage(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, ocaMsg.c_str(), ocaMsg.length());
         }
         else
         {
-            char ocaMsg[] = "VEBOX1 SCALABILITY";
-            HalOcaInterfaceNext::TraceMessage(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, ocaMsg, sizeof(ocaMsg));
+            std::stringstream ss;
+            ss << "VEBOX1 SCALABILITY. semaphoreIndex 0x" << std::hex << semaphoreIndex << " m_semaphoreAllPipesIndex 0x"
+                << std::hex  << m_semaphoreAllPipesIndex ;
+            std::string ocaMsg = ss.str();
+            HalOcaInterfaceNext::TraceMessage(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, ocaMsg.c_str(), ocaMsg.length());
         }
 
         for (int32_t i = 0; i < 2 * m_pipeNum; i++)
         {
-            HalOcaInterfaceNext::OnIndirectState(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, &m_resSemaphoreAllPipes, (m_semaphoreAllPipesIndex + i) * sizeof(uint32_t), false, sizeof(uint32_t));
+            HalOcaInterfaceNext::OnIndirectState(*cmdBuffer, (MOS_CONTEXT_HANDLE)m_osInterface->pOsContext, &m_resSemaphoreAllPipes[semaphoreIndex], (m_semaphoreAllPipesIndex % VP_SEMAPHORE_COUNT + i) * sizeof(uint32_t), false, sizeof(uint32_t));
         }
     }
 
     // memset the semaphore to avoid the semaphore was not clear during media reset
-    if ((m_semaphoreAllPipesPhase == 0) && (m_currentPipe == 0))
+    if ((m_semaphoreAllPipesPhase == 0) && (m_currentPipe == 0) && (m_semaphoreAllPipesIndex % VP_SEMAPHORE_COUNT == 0))
     {
         MOS_LOCK_PARAMS lockFlagsWriteOnly;
         MOS_ZeroMemory(&lockFlagsWriteOnly, sizeof(MOS_LOCK_PARAMS));
@@ -501,40 +580,40 @@ MOS_STATUS VpScalabilityMultiPipeNext::SyncAllPipes(PMOS_COMMAND_BUFFER cmdBuffe
 
         uint32_t *data = (uint32_t *)m_osInterface->pfnLockResource(
             m_osInterface,
-            &m_resSemaphoreAllPipes,
+            &m_resSemaphoreAllPipes[semaphoreIndex],
             &lockFlagsWriteOnly);
         SCALABILITY_CHK_NULL_RETURN(data);
-        MOS_ZeroMemory(data + m_semaphoreAllPipesIndex, 2 * m_pipeNum * sizeof(uint32_t));
+        MOS_ZeroMemory(data, VP_SEMAPHORE_COUNT * sizeof(uint32_t));
         SCALABILITY_CHK_STATUS_RETURN(m_osInterface->pfnUnlockResource(
             m_osInterface,
-            &m_resSemaphoreAllPipes));
+            &m_resSemaphoreAllPipes[semaphoreIndex]));
     }
 
     // Increment all pipe flags
     for (uint32_t i = 0; i < m_pipeNum; i++)
     {
-        if (!Mos_ResourceIsNull(&m_resSemaphoreAllPipes))
+        if (!Mos_ResourceIsNull(&m_resSemaphoreAllPipes[semaphoreIndex]))
         {
             SCALABILITY_CHK_STATUS_RETURN(SendMiAtomicDwordCmd(
-                &m_resSemaphoreAllPipes, (m_semaphoreAllPipesIndex + m_semaphoreAllPipesPhase * m_pipeNum + i) * sizeof(uint32_t), 1, MHW_MI_ATOMIC_INC, cmdBuffer));
+                &m_resSemaphoreAllPipes[semaphoreIndex], (m_semaphoreAllPipesIndex % VP_SEMAPHORE_COUNT + m_semaphoreAllPipesPhase * m_pipeNum + i) * sizeof(uint32_t), 1, MHW_MI_ATOMIC_INC, cmdBuffer));
         }
     }
 
-    if (!Mos_ResourceIsNull(&m_resSemaphoreAllPipes))
+    if (!Mos_ResourceIsNull(&m_resSemaphoreAllPipes[semaphoreIndex]))
     {
         // Waiting current pipe flag euqal to pipe number which means other pipes are executing
         SCALABILITY_CHK_STATUS_RETURN(SendHwSemaphoreWaitCmd(
-            &m_resSemaphoreAllPipes, (m_semaphoreAllPipesIndex + m_semaphoreAllPipesPhase * m_pipeNum + m_currentPipe) * sizeof(uint32_t), m_pipeNum, MHW_MI_SAD_EQUAL_SDD, cmdBuffer));
+            &m_resSemaphoreAllPipes[semaphoreIndex], (m_semaphoreAllPipesIndex % VP_SEMAPHORE_COUNT + m_semaphoreAllPipesPhase * m_pipeNum + m_currentPipe) * sizeof(uint32_t), m_pipeNum, MHW_MI_SAD_EQUAL_SDD, cmdBuffer));
 
         // Reset current pipe semaphore
         SCALABILITY_CHK_STATUS_RETURN(AddMiStoreDataImmCmd(
-            &m_resSemaphoreAllPipes, (m_semaphoreAllPipesIndex + m_semaphoreAllPipesPhase * m_pipeNum + m_currentPipe) * sizeof(uint32_t), cmdBuffer));
+            &m_resSemaphoreAllPipes[semaphoreIndex], (m_semaphoreAllPipesIndex % VP_SEMAPHORE_COUNT + m_semaphoreAllPipesPhase * m_pipeNum + m_currentPipe) * sizeof(uint32_t), cmdBuffer));
     }
 
     m_semaphoreAllPipesPhase = 1 - m_semaphoreAllPipesPhase;
     if ((m_semaphoreAllPipesPhase == 0) && (m_currentPipe == 1))
     {
-        m_semaphoreAllPipesIndex = (m_semaphoreAllPipesIndex + 2 * m_pipeNum) % VP_SEMAPHORE_COUNT;
+        m_semaphoreAllPipesIndex = (m_semaphoreAllPipesIndex + 2 * m_pipeNum) % (VP_SEMAPHORE_COUNT * 2);
     }
 
     return MOS_STATUS_SUCCESS;
