@@ -177,7 +177,22 @@ static bool InitMtlMediaSkuExt(struct GfxDeviceInfo *devInfo,
     MEDIA_WR_SKU(skuTable, FtrHcpDecMemoryCompression, 0);
     MEDIA_WR_SKU(skuTable, Ftr10bitDecMemoryCompression, 0);
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    uint32_t value = 0;
+    ReadUserSettingForDebug(
+        userSettingPtr,
+        value,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_MEDIA_CCS,
+        MediaUserSetting::Group::Device);
+
+    /* MEDIA_CSS default value is 1 */
+    if (value > 1)
+        value = 1;
+
+    MEDIA_WR_SKU(skuTable, FtrCCSNode, (uint8_t)value);
+#else
     MEDIA_WR_SKU(skuTable, FtrCCSNode, 1);
+#endif
 
     MEDIA_WR_SKU(skuTable, FtrVpP010Output, 1);
     MEDIA_WR_SKU(skuTable, FtrVp10BitSupport, 1);
@@ -286,6 +301,12 @@ static bool InitMtlMediaWaExt(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_WA(waTable, Wa_Vp9UnalignedHeight, 1);
 
+    MEDIA_WR_WA(waTable, Wa_AvcUnalignedHeight, 1);
+
+    MEDIA_WR_WA(waTable, Wa_15013355402, 1);
+
+    MEDIA_WR_WA(waTable, Wa_16021867713, 1);
+
     return true;
 }
 
@@ -299,3 +320,38 @@ static struct LinuxDeviceInit mtlDeviceInit =
 
 static bool mtlDeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
     RegisterDevice(IGFX_METEORLAKE, &mtlDeviceInit);
+
+static bool InitArlMediaSku(struct GfxDeviceInfo *devInfo,
+    MediaFeatureTable *                            skuTable,
+    struct LinuxDriverInfo                        *drvInfo,
+    MediaUserSettingSharedPtr                      userSettingPtr)
+{
+    if (!InitMtlMediaSkuExt(devInfo, skuTable, drvInfo, userSettingPtr))
+    {
+        return false;
+    }
+
+    return true;
+}
+
+static bool InitArlMediaWa(struct GfxDeviceInfo *devInfo,
+    MediaWaTable *                                waTable,
+    struct LinuxDriverInfo *                      drvInfo)
+{
+    if (!InitMtlMediaWaExt(devInfo, waTable, drvInfo))
+    {
+        return false;
+    }
+
+    return true;
+}
+
+static struct LinuxDeviceInit arlDeviceInit =
+{
+    .productFamily    = (uint32_t)IGFX_ARROWLAKE,
+    .InitMediaFeature = InitArlMediaSku,
+    .InitMediaWa      = InitArlMediaWa,
+};
+
+static bool arlDeviceRegister = DeviceInfoFactory<LinuxDeviceInit>::
+    RegisterDevice((uint32_t)IGFX_ARROWLAKE, &arlDeviceInit);
