@@ -671,25 +671,29 @@ void GpuContextSpecificNext::Clear()
     }
     MOS_FreeMemAndSetNull(m_statusBufferResource);
 
-    MosUtilities::MosLockMutex(m_cmdBufPoolMutex);
-
-    if (m_cmdBufMgr)
+    if(m_cmdBufPoolMutex)
     {
-        for (auto& curCommandBuffer : m_cmdBufPool)
+        MosUtilities::MosLockMutex(m_cmdBufPoolMutex);
+
+        if (m_cmdBufMgr)
         {
-            auto curCommandBufferSpecific = static_cast<CommandBufferSpecificNext *>(curCommandBuffer);
-            if (curCommandBufferSpecific == nullptr)
-                continue;
-            curCommandBufferSpecific->waitReady(); // wait ready and return to comamnd buffer manager.
-            m_cmdBufMgr->ReleaseCmdBuf(curCommandBuffer);
+            for (auto& curCommandBuffer : m_cmdBufPool)
+            {
+                auto curCommandBufferSpecific = static_cast<CommandBufferSpecificNext *>(curCommandBuffer);
+                if (curCommandBufferSpecific == nullptr)
+                    continue;
+                curCommandBufferSpecific->waitReady(); // wait ready and return to comamnd buffer manager.
+                m_cmdBufMgr->ReleaseCmdBuf(curCommandBuffer);
+            }
         }
+
+        m_cmdBufPool.clear();
+
+        MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
+        MosUtilities::MosDestroyMutex(m_cmdBufPoolMutex);
+        m_cmdBufPoolMutex = nullptr;
     }
 
-    m_cmdBufPool.clear();
-
-    MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
-    MosUtilities::MosDestroyMutex(m_cmdBufPoolMutex);
-    m_cmdBufPoolMutex = nullptr;
     MOS_SafeFreeMemory(m_commandBuffer);
     m_commandBuffer = nullptr;
     MOS_SafeFreeMemory(m_allocationList);
@@ -1215,7 +1219,7 @@ MOS_STATUS GpuContextSpecificNext::MapResourcesToAuxTable(mos_linux_bo *cmd_bo)
     MOS_OS_CHK_NULL_RETURN(osCtx);
 
     AuxTableMgr *auxTableMgr = osCtx->GetAuxTableMgr();
-    if (auxTableMgr)
+    if (auxTableMgr && m_currentNumPatchLocations > 0)
     {
         // Map compress allocations to aux table if it is not mapped.
         for (uint32_t i = 0; i < m_numAllocations; i++)
@@ -1975,7 +1979,7 @@ PMOS_RESOURCE GpuContextSpecificNext::GetOcaRTLogResource(PMOS_RESOURCE globalIn
     // than 2 video processors, the value may be overwritten and wrong allocation Index in array may be used.
     // To avoid this, use duplicate MOS_RESOURCE instance in GPU Context to ensure differnt iAllocationIndex
     // array of OcaRTLogResources being used for different GPU Context.
-    if (!m_ocaRtLogResInited)
+    if (!m_ocaRtLogResInited && globalInst)
     {
         m_ocaRtLogResource = *globalInst;
         m_ocaRtLogResInited = true;
