@@ -35,7 +35,7 @@ public:
     template<class _Fun, class... _Types>
     static void MOS_DEVULT_FuncCall(_Fun fun, _Types&&... ags)
     {
-        if (MosUtilities::m_mosUltFlag && fun)
+        if (MosUtilities::m_mosUltFlag && (*MosUtilities::m_mosUltFlag) && fun)
         {
             fun(std::forward<_Types>(ags)...);
         }
