@@ -42,8 +42,6 @@ static pthread_mutex_t command_dump_mutex = PTHREAD_MUTEX_INITIALIZER;
 GpuContextSpecificNextXe::~GpuContextSpecificNextXe()
 {
     MOS_OS_FUNCTION_ENTER;
-
-    Clear();
 }
 
 MOS_STATUS GpuContextSpecificNextXe::Init3DCtx(PMOS_CONTEXT osParameters,
@@ -250,11 +248,6 @@ MOS_STATUS GpuContextSpecificNextXe::InitBltCtx(PMOS_CONTEXT osParameters,
     return eStatus;
 }
 
-void GpuContextSpecificNextXe::Clear()
-{
-    MOS_OS_FUNCTION_ENTER;
-}
-
 MOS_STATUS GpuContextSpecificNextXe::PatchCommandBuffer(
     MOS_STREAM_HANDLE   streamState,
     PMOS_COMMAND_BUFFER cmdBuffer)
