@@ -179,6 +179,7 @@ MOS_STATUS MhwInterfacesXe_Lpm_Plus_Next::Initialize(
     // MHW_CP and MHW_MI must always be create
     MOS_STATUS status;
     m_cpInterface = osInterface->pfnCreateMhwCpInterface(osInterface);
+    MHW_MI_CHK_NULL(m_cpInterface);
     auto ptr      = std::make_shared<mhw::mi::xe_lpm_plus_base_next::Impl>(osInterface);
     m_miItf       = std::static_pointer_cast<mhw::mi::Itf>(ptr);
     ptr->SetCpInterface(m_cpInterface, m_miItf);
@@ -302,57 +303,6 @@ static bool mtlRegisteredMcpy =
     MediaFactory<uint32_t, McpyDeviceNext>::
     Register<McpyDeviceXe_Lpm_Plus>((uint32_t)IGFX_METEORLAKE);
 
-MOS_STATUS McpyDeviceXe_Lpm_Plus::Initialize(
-    PMOS_INTERFACE osInterface,
-    MhwInterfacesNext *mhwInterfaces)
-{
-#define MCPY_FAILURE()                                       \
-{                                                           \
-    if (device != nullptr)                                  \
-    {                                                       \
-        MOS_Delete(device);                                 \
-    }                                                       \
-    return MOS_STATUS_NO_SPACE;                             \
-}
-
-    MHW_FUNCTION_ENTER;
-
-    Mcpy *device = nullptr;
-
-    if (nullptr == mhwInterfaces->m_miItf)
-    {
-        MCPY_FAILURE();
-    }
-
-    if (nullptr == mhwInterfaces->m_veboxItf)
-    {
-        MCPY_FAILURE();
-    }
-
-    if (nullptr == mhwInterfaces->m_bltItf)
-    {
-        MCPY_FAILURE();
-    }
-
-    device = MOS_New(Mcpy);
-
-    if (device == nullptr)
-    {
-        MCPY_FAILURE();
-    }
-
-    if (device->Initialize(
-        osInterface, mhwInterfaces) != MOS_STATUS_SUCCESS)
-    {
-        MOS_Delete(device);
-        MOS_OS_CHK_STATUS_RETURN(MOS_STATUS_UNINITIALIZED);
-    }
-
-    m_mcpyDevice = device;
-
-    return MOS_STATUS_SUCCESS;
-}
-
 static bool mtlRegisteredCodecHal =
     MediaFactory<uint32_t, CodechalDeviceNext>::
         Register<CodechalInterfacesXe_Lpm_Plus>((uint32_t)IGFX_METEORLAKE);
@@ -397,14 +347,12 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
     if (debugInterface == nullptr)
     {
         MOS_Delete(hwInterface);
-        mhwInterfaces->SetDestroyState(true);
         CODECHAL_PUBLIC_ASSERTMESSAGE("debugInterface is not valid!");
         return MOS_STATUS_NO_SPACE;
     }
     if (debugInterface->Initialize(hwInterface, CodecFunction) != MOS_STATUS_SUCCESS)
     {
         MOS_Delete(hwInterface);
-        mhwInterfaces->SetDestroyState(true);
         MOS_Delete(debugInterface);
         CODECHAL_PUBLIC_ASSERTMESSAGE("Debug interface creation failed!");
         return MOS_STATUS_INVALID_PARAMETER;
@@ -413,6 +361,14 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
     CodechalDebugInterface *debugInterface = nullptr;
 #endif  // USE_CODECHAL_DEBUG_TOOL
 
+    auto release_func = [&]() 
+    {
+        MOS_Delete(hwInterface);
+#if USE_CODECHAL_DEBUG_TOOL
+        MOS_Delete(debugInterface);
+#endif  // USE_CODECHAL_DEBUG_TOOL
+    };
+
     if (CodecHalIsDecode(CodecFunction))
     {
 #ifdef _MPEG2_DECODE_SUPPORTED
@@ -475,7 +431,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
 #endif
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Decode mode requested invalid!");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
 
         if (m_codechalDevice == nullptr)
@@ -486,7 +442,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             MOS_Delete(debugInterface);
 #endif
             CODECHAL_PUBLIC_ASSERTMESSAGE("Decoder device creation failed!");
-            return MOS_STATUS_NO_SPACE;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_NO_SPACE, release_func);
         }
     }
     else if (CodecHalIsEncode(CodecFunction))
@@ -500,14 +456,14 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
                 if (m_codechalDevice == nullptr)
                 {
                     CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                    return MOS_STATUS_INVALID_PARAMETER;
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
                 }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, AVC VME Encoder is not supported, please use AVC LowPower Encoder instead!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
@@ -519,7 +475,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (m_codechalDevice == nullptr)
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
             return MOS_STATUS_SUCCESS;
         }
@@ -528,7 +484,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
         if (info->Mode == CODECHAL_ENCODE_MODE_MPEG2)
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, MPEG2 Encoder is not supported!");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
         else
 #ifdef _JPEG_ENCODE_SUPPORTED
@@ -538,7 +494,7 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (m_codechalDevice == nullptr)
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
             return MOS_STATUS_SUCCESS;
         }
@@ -550,12 +506,16 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
             if (CodecHalUsesVdencEngine(info->CodecFunction))
             {
                 m_codechalDevice = MOS_New(EncodeAv1VdencPipelineAdapterXe_Lpm_Plus, hwInterface, debugInterface);
-                CODECHAL_PUBLIC_CHK_NULL_RETURN(m_codechalDevice);
+                if (m_codechalDevice == nullptr)
+                {
+                    CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
+                }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
@@ -569,27 +529,27 @@ MOS_STATUS CodechalInterfacesXe_Lpm_Plus::Initialize(
                 if (m_codechalDevice == nullptr)
                 {
                     CODECHAL_PUBLIC_ASSERTMESSAGE("Encode state creation failed!");
-                    return MOS_STATUS_INVALID_PARAMETER;
+                    CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
                 }
                 return MOS_STATUS_SUCCESS;
             }
             else
             {
                 CODECHAL_PUBLIC_ASSERTMESSAGE("Encode allocation failed, HEVC VME Encoder is not supported.");
-                return MOS_STATUS_INVALID_PARAMETER;
+                CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
             }
         }
         else
 #endif
         {
             CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported encode function requested.");
-            return MOS_STATUS_INVALID_PARAMETER;
+            CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
         }
     }
     else
     {
         CODECHAL_PUBLIC_ASSERTMESSAGE("Unsupported codec function requested.");
-        return MOS_STATUS_INVALID_PARAMETER;
+        CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(MOS_STATUS_INVALID_PARAMETER, release_func);
     }
 
     return MOS_STATUS_SUCCESS;
